<?php

namespace App\Http\Controllers;

use App\Models\Appointment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

use Yajra\DataTables\Facades\DataTables;

class AppointmentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function index(Request $req)
    {
        if (\request()->ajax()) {
            $list = Appointment::query();
            $branche = $req->branche_id ?: auth()->user()->branche_id;
            if ($branche) {
                $list->where(function ($q) use ($branche) {
                    $q->where('branche_id', $branche);
                });
            }
            $datatable = DataTables::of($list)
                ->addColumn('clientname', function ($item) {
                    return optional($item->client)->name;
                })
                ->addColumn('mobile', function ($item) {
                    return optional($item->client)->mobile;
                })
                ->addColumn('model', function ($item) {
                    $car = optional($item->car);
                    return $car->car_brand . ' - ' . $car->model . ' - ' . $car->color;
                })

                ->addColumn('actions', function ($prod) {
                    $currentUser = auth()->user();
                    $btn = '';

                    if ($currentUser->can('Edit Appointments')) {
                        $btn .= ' <a title = "تعديل" href = "' . route('appointments.edit', $prod) . '" class="btn btn-primary btn-xs" >
                            <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                            </a >';
                    }
                    if ($currentUser->can('Delete Appointments')) {
                        $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="' . route('appointments.destroy', $prod) . '" data-id="' . $prod->id . '">
                            <i class="fa fa-trash"></i>
                        </a>';
                    }

                    return $btn;
                });
            $datatable->rawColumns(['image', 'actions']);
            return $datatable->make(true);
        }
        return view('appointments.index');
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (\request()->ajax()) {
            return view('appointments.ajax');
        } else {
            return view('appointments.create');
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $inputs['creator_id'] = auth()->user()->id;
            if (auth()->user()->branche_id) {
                $inputs['branche_id'] = auth()->user()->branche_id;
            }
            $appointment = Appointment::query()->create($inputs);

            DB::commit();
            return back()->with('alert-success', 'تمت الإضافة بنجاح');
        } catch (\Exception $e) {
            DB::rollBack();
            return back()->with('alert-danger', $e->getMessage());
            //dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $appointment = Appointment::filter()->find($id);
        return view('appointments.show', compact('appointment'));
    }
    public function getQuest($id)
    {
        $item = Appointment::filter()->find($id);
        return view('appointments.quest_detailes', compact('item'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Appointment $appointment)
    {
        $person = $appointment->client;
        return view('appointments.edit', ['item' => $appointment, 'per' => $person]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Appointment $appointment)
    {
        $inputs = $request->except('_token');
        $appointment->update($inputs);
        return back()->with('alert-success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Appointment $appointment)
    {
        if ($appointment->delete()) {
            return "done";
        }
        return "failed";
    }

}