<?php

namespace App\Http\Controllers;

use App\Models\ClientCar;
use App\Models\Lookup;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

use Yajra\DataTables\Facades\DataTables;

class ClientCarController extends Controller
{
    public function index(Request $req)
    {
        if (\request()->ajax()) {
            $list = ClientCar::query();
            $branche = $req->branche_id ?: auth()->user()->branche_id;
            if ($branche) {
                $list->where(function ($q) use ($branche) {
                    $q->where('branche_id', $branche);
                });
            }
            $datatable = DataTables::of($list)
                ->addColumn('clientname', function ($prod) {
                    return '<a href="' . route('clients.show', $prod->client_id) . '">' . optional($prod->client)->name . '</a>';
                })

                ->addColumn('actions', function ($prod) {
                    $currentUser = auth()->user();
                    $btn = '';
                    //if ($currentUser->can('Edit ClientCars')) {
                    $btn .= ' <a  title = "تعديل" href = "' . route('clientcars.edit', $prod) . '" class="btn btn-primary btn-xs" >
                            <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                            </a >';
                    //}
                    //if ($currentUser->can('Delete ClientCars')) {
                    $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="' . route('clientcars.destroy', $prod) . '" data-id="' . $prod->id . '">
                            <i class="fa fa-trash"></i>
                        </a>';
                    //}
    
                    return $btn;
                });
            $datatable->rawColumns(['image', 'actions', 'clientname']);
            return $datatable->make(true);
        }
        return view('clientcars.index');
    }

    public function getClientCarList()
    {
        $list = ClientCar::query();
        if (auth()->user()->branche_id) {
            $list->where('branche_id', auth()->user()->branche_id);
        }
        $term = request('term');
        $results = array();
        if (!$term)
            return response()->json($results);
        $list = $list->where('name', 'LIKE', '%' . $term . '%')->get();
        foreach ($list as $query) {
            $results[] = ['id' => $query->id, 'text' => $query->name];
        }
        return response()->json($results);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (\request()->ajax()) {
            return view('clientcars.ajax');
        } else {
            return view('clientcars.create');
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            DB::beginTransaction();
            $inputs = $request->except('_token', 'reqType');
            if (auth()->user()->branche_id) {
                $inputs['branche_id'] = auth()->user()->branche_id;
            }
            if ($inputs['chassis_no']) {
                $search = ClientCar::where('chassis_no', $inputs['chassis_no'])->first();
                if ($search) {
                    throw new \Exception('خطأ رقم الهيكل مسجل  ' . $search->name);
                }
            }
            $client = ClientCar::query()->firstOrCreate($inputs, $inputs);
            if ($request->attachments) {
                foreach ($request->attachments as $file) {
                    $client->addMedia($file)->toMediaCollection('attachments');
                }
            }
            DB::commit();
            if (request()->reqType == 'ajax') {
                $clients = ClientCar::query()->get();
                return view('clientcars.dropdown', compact('clients'));
            }
            return back()->with('alert-success', 'تمت الإضافة بنجاح');
        } catch (\Exception $e) {
            DB::rollBack();
            return back()->with('alert-danger', $e->getMessage());
            //dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $client = ClientCar::filter()->find($id);
        return view('clientcars.show', compact('client'));
    }




    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(ClientCar $clientcar)
    {
        return view('clientcars.edit', ['client' => $clientcar]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, ClientCar $clientcar)
    {
        $inputs = $request->except('_token');
        $clientcar->update($inputs);

        if (isset($inputs['mediaTodelete'])) {
            Media::whereIn('id', $inputs['mediaTodelete'])->delete();
        }
        if ($request->attachments) {
            foreach ($request->attachments as $file) {
                $clientcar->addMedia($file)->toMediaCollection('attachments');
            }
        }
        return back()->with('alert-success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(ClientCar $clientcar)
    {
        if ($clientcar->delete()) {
            return "done";
        }
        return "failed";
    }
    public function getClientCarsList(Request $request)
    {
        $searchKeyword = $request->term;
        $client_id = request('client_id');
        $query = ClientCar::query();
        if ($client_id) {
            $query->where('client_id', $client_id);
        }
        if ($searchKeyword) {
            $query->where(function ($q) use ($searchKeyword) {
                $q->whereRaw('LOWER(model) like "%' . strtolower($searchKeyword) . '%"');
                $q->orwhereRaw('LOWER(chassis_no) like "%' . strtolower($searchKeyword) . '%"');
                $q->orwhereRaw('LOWER(car_number) like "%' . strtolower($searchKeyword) . '%"');
            });
        }
        $queries = $query->take(25)
            ->get();
        $results = [];
        foreach ($queries as $query) {
            $results[] = ['id' => $query->id, 'text' => $query->car_number . " - " . $query->car_brand . " - " . $query->model];
        }
        return response()->json($results);
    }

}