<?php

namespace App\Http\Controllers;

use App\Models\Client;
use App\Models\Lookup;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

use Yajra\DataTables\Facades\DataTables;

class ClientController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        view()->composer(['clients._form'], function ($view) {
            $lookupList = Lookup::query()->get();
            $brands = $lookupList->whereNull('parent_id')->where('type', 'brand')->all();
            $models = $lookupList->whereNotNull('parent_id')->where('type', 'brand')->all();
            $colors = $lookupList->where('type', 'color')->all();
            $view->with([
                'brands' => $brands,
                'models' => $models,
                'colors' => $colors
            ]);
        });
        parent::__construct();
    }
    public function index(Request $req)
    {
        if (\request()->ajax()) {
            $list = Client::query();
            $branche = $req->branche_id ?: auth()->user()->branche_id;
            if ($branche) {
                $list->where(function ($q) use ($branche) {
                    $q->where('branche_id', $branche);
                });
            }
            $datatable = DataTables::of($list)
                ->addColumn('image', function ($prod) {
                    //return '<img style="width: 80px;" src="'.optional($prod->getFirstMedia('images'))->getUrl().'" />';
                })

                ->addColumn('actions', function ($prod) {
                    $currentUser = auth()->user();
                    $btn = '';

                    if ($currentUser->can('Edit Clients')) {
                        $btn .= ' <a data-toggle="modal" data-target="#myModal" title = "تعديل" href = "' . route('clients.edit', $prod) . '" class="btn btn-primary btn-xs" >
                            <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                            </a >';
                    }
                    if ($currentUser->can('Delete Clients')) {
                        $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="' . route('clients.destroy', $prod) . '" data-id="' . $prod->id . '">
                            <i class="fa fa-trash"></i>
                        </a>';
                    }

                    return $btn;
                });
            $datatable->rawColumns(['image', 'actions']);
            return $datatable->make(true);
        }
        return view('clients.index');
    }

    public function getClientList()
    {
        $list = Client::query();
        if (auth()->user()->branche_id) {
            $list->where('branche_id', auth()->user()->branche_id);
        }
        $term = request('term');
        $results = array();
        if (!$term)
            return response()->json($results);
        $list = $list->where('name', 'LIKE', '%' . $term . '%')->get();
        foreach ($list as $query) {
            $results[] = ['id' => $query->id, 'text' => $query->name];
        }
        return response()->json($results);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (\request()->ajax()) {
            return view('clients.ajax');
        } else {
            return view('clients.create');
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            DB::beginTransaction();
            $inputs = $request->except('_token', 'reqType');
            if (auth()->user()->branche_id) {
                $inputs['branche_id'] = auth()->user()->branche_id;
            }
            if ($inputs['id_number']) {
                $search = Client::where('id_number', $inputs['id_number'])->first();
                if ($search) {
                    throw new \Exception('خطأ رقم الهوية مسجل مع شخص أخر وهو ' . $search->name);
                }
            }
            $client = Client::query()->firstOrCreate($inputs, $inputs);
            if ($request->attachments) {
                foreach ($request->attachments as $file) {
                    $client->addMedia($file)->toMediaCollection('attachments');
                }
            }
            DB::commit();
            if (request()->reqType == 'ajax') {
                $clients = Client::query()->get();
                return view('clients.dropdown', compact('clients'));
            }
            return back()->with('alert-success', 'تمت الإضافة بنجاح');
        } catch (\Exception $e) {
            DB::rollBack();
            return back()->with('alert-danger', $e->getMessage());
            //dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $client = Client::filter()->find($id);
        return view('clients.show', compact('client'));
    }
    public function getQuest($id)
    {
        $item = Client::filter()->find($id);
        return view('clients.quest_detailes', compact('item'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Client $client)
    {
        return view('clients.edit', ['client' => $client]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Client $client)
    {
        $inputs = $request->except('_token');
        $inputs['is_merchant'] = $request->has('is_merchant');
        $client->update($inputs);

        if (isset($inputs['mediaTodelete'])) {
            Media::whereIn('id', $inputs['mediaTodelete'])->delete();
        }
        if ($request->attachments) {
            foreach ($request->attachments as $file) {
                $client->addMedia($file)->toMediaCollection('attachments');
            }
        }
        return back()->with('alert-success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Client $client)
    {
        if ($client->delete()) {
            return "done";
        }
        return "failed";
    }

    public function getClientsList()
    {
        $term = request('term');
        $results = array();
        $queries = Client::query();
        if ($term) {
            $queries->whereRaw('LOWER(name) like "%' . strtolower($term) . '%"');
            $queries->orwhereRaw('LOWER(mobile) like "%' . strtolower($term) . '%"');
            $queries->orwhereRaw('LOWER(id_number) like "%' . strtolower($term) . '%"');
        }
        $queries = $queries->take(20)->get();
        foreach ($queries as $query) {
            $results[] = ['id' => $query->id, 'text' => $query->id . " - " . $query->name . " - " . $query->mobile];
        }
        return response()->json($results);
    }

}