<?php

namespace App\Http\Controllers;

use App\Models\Client;
use App\Models\Department;
use App\Models\Offer;
use App\Models\OfferService;
use App\Models\Product;
use App\Models\User;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

class OffersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        view()->composer('offers._form',function($view){
            $view->with([
                'products'=>Product::get(),
                'persons'=>Client::get()
            ]);
        });
        parent::__construct();
    }

    public function index()
    {
        $list = Offer::query()->filter();
        if(auth()->user()->branche_id){
            $list->where('branche_id',auth()->user()->branche_id);
        }
        $list = $list->latest()->get();
        return view('offers.index',compact('list'));
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('offers.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $inputs['invoice']['creator_id'] = auth()->user()->id;
            if(auth()->user()->branche_id){
                $inputs['invoice']['branche_id'] = auth()->user()->branche_id;
            }
            $offer = Offer::create($inputs['invoice']);
            //$offer->services()->delete();
            if(isset($inputs['service'])){
                $servicesList = [];
                foreach($inputs['service']['title'] as $i=>$serv){
                    $servicesList[] = [
                        'title'=>$inputs['service']['title'][$i],
                        'price'=>$inputs['service']['price'][$i],
                        'offer_id'=>$offer->id
                    ];
                }
                OfferService::query()->insert($servicesList);
            }
            if($request->image){
                foreach ($request->image as $file){
                    $offer->addMedia($file)->toMediaCollection('images');
                }
            }
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $offer->addMedia($file)->toMediaCollection('attachments');
                }
            }
            $trans["trans_date"] = date('Y-m-d');
            $trans['creator_id']= auth()->user()->id;
            $trans["branche_id"] = auth()->user()->branche_id;
            if(isset($inputs['prod'])){
                $offer->details()->attach($inputs['prod']);
            }
            DB::commit();
            return redirect(route('offers.index'))->with('alert-success', 'تمت الإضافة بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $order = Offer::withTrashed()->with(['details'])->find($id);
        return view('offers.print',compact('order'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Offer $offer)
    {
        return view('offers.edit',['item'=>$offer]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Offer $offer)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $offer->update($inputs['invoice']);
            $offer->services()->delete();
            if(isset($inputs['service'])){
                $servicesList = [];
                foreach($inputs['service']['title'] as $i=>$serv){
                    $servicesList[] = [
                        'title'=>$inputs['service']['title'][$i],
                        'price'=>$inputs['service']['price'][$i],
                        'offer_id'=>$offer->id
                    ];
                }
                OfferService::query()->insert($servicesList);
            }
            if (isset($inputs['mediaTodelete'])) {
                Media::whereIn('id', $inputs['mediaTodelete'])->delete();
            }
            if($request->image){
                foreach ($request->image as $file){
                    $offer->addMedia($file)->toMediaCollection('images');
                }
            }
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $offer->addMedia($file)->toMediaCollection('attachments');
                }
            }
            $offer->details()->detach();
            if(isset($inputs['prod'])){
                $offer->details()->attach($inputs['prod']);
            }
            DB::commit();
            return redirect(route('offers.index'))->with('alert-success', 'تم التعديل بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
            return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Offer $offer)
    {
        if($offer->delete()){
            return "done";
        }
        return "failed";
    }


    public function addPayment(Request $request,$order_id){
        $order = Offer::find($order_id);
        $person = Client::find($order->client_id);
        if($request->isMethod('post')){
            try{
                $inputs = $request->except('_token');
                $inputs['creator_id'] = auth()->user()->id;
                if(auth()->user()->branche_id){
                    $inputs['branche_id'] = auth()->user()->branche_id;
                }
                $inputs['value']= -$inputs['value'];
                $transaction =  $order->transactions()->create($inputs);
                if ($request->has('image')) {
                    $transaction->addMedia($request->file('image'))->toMediaCollection('images');
                }
                return redirect(route('transactions.show',$transaction))->with('alert-success', 'تمت الإضافة بنجاح');
            }catch(Exception $e){
                dd($e->getMessage());
            }
        }
        return view('offers.payment',compact('person','order'));
    }
}
