<?php

namespace App\Http\Controllers;

use App\Models\Branche;
use App\Models\Client;
use App\Models\Department;
use App\Models\Invoice;
use App\Models\Mission;
use App\Models\OrderTask;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

class OrderTaskController extends Controller
{
    public function __construct()
    {
        view()->composer(['order_task.*','_partial.taskfilter'],function($view){
            $users = User::query();
            $persons = Client::query();
            $branches = Branche::query();
            $userBrancheId = auth()->user()->branche_id;
            if($userBrancheId){
                $users->where('branche_id',$userBrancheId);
                $persons->where('branche_id',$userBrancheId);
                $branches->where('id',$userBrancheId);
            }
            $users = $users->get();
            $persons = $persons->get();
            $branches = $branches->get();
            $view->with([
                'departments'=>Department::get(),
                'users'=>$users,
                'tasks'=>Mission::get(),
                'persons'=>$persons,
                'branches'=>$branches
            ]);
        });
        parent::__construct();
    }
    public function index()
    {
        $list = OrderTask::query()->filter();
        if(auth()->user()->roles[0]->id!=1){
            $list->where(function($query){
                $query->whereNull('user_id');
                if(auth()->user()->dep_id) {
                    $query->wherein('department_id', auth()->user()->dep_id);
                }
            })->orwhere(function($query){
                $query->where('user_id',auth()->user()->id);
                /*if(auth()->user()->dep_id) {
                    $query->wherein('department_id', auth()->user()->dep_id);
                }*/
            });
        }
        $list = $list->orderBy('id','DESC')->paginate();
        return view('order_task.index',compact('list'));
    }


    public function create()
    {
        $ordertask = new OrderTask();
        return view('order_task.create',compact('ordertask'));
    }

    public function edit(OrderTask $ordertask)
    {
        $order = $ordertask->order;
        if(request()->ajax()){
            return view('order_task.editajax',compact('ordertask'));
        }
        return view('order_task.edit',compact('ordertask','order'));
    }
    public function show(OrderTask $ordertask)
    {
        return view('order_task.show',compact('ordertask'));
    }

    public function preview(OrderTask $ordertask)
    {
        return view('order_task.preview',compact('ordertask'));
    }

    public function serviceform(OrderTask $ordertask)
    {
        $order = $ordertask->order;
        return view('order_task.serviceform',compact('order'));
    }
    public function exceptionrequest(OrderTask $ordertask)
    {
        $order = $ordertask->order;
        return view('order_task.exceptionrequest',compact('order'));
    }

    public function uploadfiles(Request $request,OrderTask $ordertask)
    {
        if($request->isMethod('POST')){
            if ($request->file('images')) {
                foreach($request->file('images') as $img){
                    $ordertask->addMedia($img)->toMediaCollection('images');
                }
            }
            return back()->with('alert-success','تم رفع المرفقات بنجاح');
        }
        return view('order_task.uploadfiles',compact('ordertask'));
    }



    public function store(Request $request)
    {
        $inputs = $request->except('_token','_method');
        if(!isset($inputs['branche_id']) && auth()->user()->branche_id){
            $inputs['branche_id'] = auth()->user()->branche_id;
        }
        $inputs['must_completed'] = request()->has('must_completed');
        //dd($inputs);
        $ordertask = OrderTask::query()->create($inputs);
        if($request->file('images')) {
            foreach($request->file('images') as $img){
                $ordertask->addMedia($img)->toMediaCollection('images');
            }
        }
        if(in_array($ordertask->mission_id,[1,6])){
            $ordertask->status = "قبول";
            $ordertask->save();
            $this->makeOrder($ordertask->id);
        }
        return redirect()->route('ordertasks.index')->with('alert-success','تم التعديل بنجاح');
    }
    public function update(Request $request,OrderTask $ordertask)
    {
        $input = $request->except('_token','_method');

        $input['must_completed'] = request()->has('must_completed');
        if($ordertask->order_id){
           $order = Invoice::find($ordertask->order_id);
        //    $due = $order->total_due;
        //    if($order->payment != 'تمويل' && $due > 0){
        //         $due = number_format($due);
        //         return back()->with('alert-danger','لا يمكن قبول المهمة إلا بعد دفع مبلغ الفاتورة بالكامل '.$due);
        //    }
           $check =  OrderTask::where('order_id',$ordertask->order_id)
                        ->where('id','<',$ordertask->id)
                        ->where('status','<>','قبول')
                        ->count();
            if($check){
                return back()->with('alert-danger','يجب قبول المهمات السابقة لكى تستطيع تنفيذ هذه المهمة');
            }

        }
        $ordertask->action_at = now();
        $ordertask->update($input);
        if($ordertask->status=="رفض"){
            $prevTask = OrderTask::where('order_id',$ordertask->order_id)
            ->where('id','<',$ordertask->id)
            ->orderBy('id','DESC')
            ->first();
            if($prevTask){
                $prevTask->status = "معلق";
                $prevTask->note = $ordertask->note;
                $prevTask->save();
            }
        }
        if(isset($input['mediaTodelete'])){
            Media::whereIn('id', $input['mediaTodelete'])->delete();
        }
        if ($request->file('images')) {
            foreach($request->file('images') as $img){
                $ordertask->addMedia($img)->toMediaCollection('images');
            }
        }
        return back()->with('alert-success','تم التعديل بنجاح');
    }

    public function destroy(OrderTask $ordertask){
        if($ordertask->delete()){
            return "done";
        }
        return "failed";
    }

    public function addInvoiceTask($tasksList){
        OrderTask::query()->insert($tasksList);
    }

}
