<?php
namespace App\Http\Controllers;

use App\Models\Branche;
use App\Models\Product;
use App\Models\ProductBranche;
use Illuminate\Http\Request;
use DB;
use Yajra\DataTables\Facades\DataTables;

class ProductController extends Controller
{

    public function __construct()
    {
        view()->composer(['_partial.productfilter'],function($view){

            $branches = Branche::query();
            $userBrancheId = auth()->user()->branche_id;
            if($userBrancheId){
                $branches->where('id',$userBrancheId);
            }
            $branches = $branches->get();
            $view->with([
                'branches'=>$branches,
            ]);
        });

        parent::__construct();
    }
    public function index(Request $req){
        if (\request()->ajax()) {
            $list = Product::query()->filter();
            $branche = $req->branche_id?:auth()->user()->branche_id;
            // if($branche){
            //     $list->where(function($q)use($branche){
            //         $q->where('branche_id',$branche);
            //     });
            // }
            $datatable = DataTables::of($list)
                    ->addColumn('pqty',function($prod){
                        $b = $prod->productBranche()->first();
                        return $b->pivot->qty??0;
                    })
                    ->addColumn('plocation',function($prod){
                        $b = $prod->productBranche()->first();
                        return $b->pivot->location??'';
                    })
                ->addColumn('actions',function($prod){
                    $currentUser = auth()->user();
                    $btn = '';

                    if($currentUser->can('Edit Products')){
                        $btn .= ' <a data-toggle="modal" data-target="#myModal" title = "تعديل" href = "'.route('products.edit',$prod).'" class="btn btn-primary btn-xs" >
                            <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                            </a >';
                    }
                    if($currentUser->can('Delete Products')){
                        $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="'.route('products.destroy',$prod).'" data-id="'.$prod->id.'">
                            <i class="fa fa-trash"></i>
                        </a>';
                    }

                    return $btn;
                });
            $datatable->rawColumns(['image','actions']);
            return $datatable->make(true);
        }
        return view('products.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $product = new Product;
        return view('products.create',compact('product'));
    }

    /**
     * Product a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $inputs = $request->except('_token');
        if(!isset($inputs['branche_id']) && auth()->user()->branche_id){
            $inputs['branche_id'] = auth()->user()->branche_id;
        }
        $product = Product::create($inputs);
        $inputs['branche']['product_id'] = $product->id;
        ProductBranche::query()->create($inputs['branche']);
        return redirect(route('products.index'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $product = Product::findOrFail($id);
        $list = null;
        return view('products.show',compact('product','list'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $product = Product::findOrFail($id);
        $b = $product->productBranche()->first();
        return view('products.edit',compact('product','b'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $product = Product::findOrFail($id);
        $inputs = $request->except('_token');
        $product->update($inputs);
        //dd($inputs['branche']);
        ProductBranche::query()->updateOrCreate(['product_id'=>$product->id,'branche_id'=>$inputs['branche']['branche_id']],$inputs['branche']);
        return redirect(route('products.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Product $product)
    {
        if($product->delete()){
            return "done";
        }
        return "failed";
    }
    public function getProductsList()
    {
        $term = request('term');
        $type = request('type')?:'قطع غيار';
        $results = array();
        $queries = Product::query()->where('type',$type);

        $queries->whereHas('productBranche');
        if($term){
            $queries->whereRaw('LOWER(name) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(model) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(code) like "%'.strtolower($term).'%"');
        }
        $queries = $queries->take(20)->get();

        if($type!="قطع غيار"){
            return $queries->toArray();
        }

        foreach ($queries as $query) {
            $results[] = ['id' => $query->id, 'text' => $query->id. " - ".$query->name. " - ".$query->code. " - ".$query->model.' - ( الكمية المتوفرة : '.$query->current_qty.' قطعة )'.' - '.$query->price];
        }
        return response()->json($results);
    }


}
