<?php

namespace App\Http\Controllers;

use App\Models\Branche;
use App\Models\Client;
use App\Models\Purchase;
use App\Models\Product;
use App\Models\ProductBranche;
use App\Models\Supplier;
use App\Models\User;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;
use Yajra\DataTables\Facades\DataTables;

class PurchaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        view()->composer(['purchases._form','purchases.show'],function($view){
            $view->with([
                'products'=>Product::get(),
            ]);
        });
        view()->composer(['_partial.orderfilter'],function($view){
            $users = User::query();
            $persons = Client::query();
            $branches = Branche::query();
            $userBrancheId = auth()->user()->branche_id;
            if($userBrancheId){
                $users->where('branche_id',$userBrancheId);
                $persons->where('branche_id',$userBrancheId);
                $branches->where('id',$userBrancheId);
            }
            $users = $users->get();
            $persons = $persons->get();
            $branches = $branches->get();
            $view->with([
                'users'=>$users,
                'branches'=>$branches,
            ]);
        });
        parent::__construct();
    }


    public function index(){
        if (\request()->ajax()) {
            $list = Purchase::query()->filter();
            $datatable = DataTables::of($list)
            ->addColumn('supplier',function($item){
                return '<a title="المورد" href="'.route('suppliers.show',$item->supplier_id).'" class="btn btn-success btn-xs">
                <i class="fa fa-user" aria-hidden="true"></i> '.optional($item->supplier)->name.'
                </a>';
            })

            ->addColumn('branche',function($item){
                return optional($item->branche)->name;
            })
            ->addColumn('post_date',function($item){
                return $item->post_date;
            })
            ->addColumn('creator',function($item){
                return optional($item->creator)->name;
            })
            ->addColumn('total',function($item){
                return number_format($item->total);
            })
            ->addColumn('total_paid',function($item){
                return number_format($item->total_paid);
            })
            ->addColumn('total_due',function($item){
                return number_format($item->total_due);
            })
            ->addColumn('actions',function($item){
                $currentUser = auth()->user();
                $btn = '';
                $s = optional($item->currentStatus);
                if(($currentUser->can('Edit Purchases') )){
                    $btn .= '<a  title = "تعديل" href = "'.route('purchases.edit',$item).'" class="btn btn-primary btn-xs" >
                        <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                        </a >';
                }
                if($currentUser->can('addWithdraw Purchases')){
                    $btn .= ' <a title="سند صرف" data-toggle="modal" data-target="#myModal" href="'.route('purchases.addWithdraw',$item->id).'" class="btn btn-success btn-xs">
                    <i class="fa fa-money fa-fw" aria-hidden="true"></i>
                </a>';
                }
                if($currentUser->can('Show Purchases')){
                    $btn .= ' <a title="التفاصيل" href="'.route('purchases.show',$item).'" class="btn btn-warning btn-xs">
                                <i class="fa fa-pencil fa-eye" aria-hidden="true"></i>
                            </a>
                            <a title="طباعه" href="'.route('purchase.print',$item).'" class="btn btn-info btn-xs">
                                <i class="fa fa-print" aria-hidden="true"></i>
                            </a>';
                }
                if($currentUser->can('Delete Purchases')){
                    $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="'.route('purchases.destroy',$item).'" data-id="'.$item->id.'">
                        <i class="fa fa-trash"></i>
                    </a>';
                }

                return $btn;
            });
            $datatable->rawColumns(['actions','supplier']);
            return $datatable->make(true);
        }
        return view('purchases.index');
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('purchases.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $inputs['purchase']['creator_id'] = auth()->user()->id;
            if(auth()->user()->branche_id){
                $inputs['purchase']['branche_id'] = auth()->user()->branche_id;
            }
            $purchase = Purchase::create($inputs['purchase']);
            if($request->image){
                foreach ($request->image as $file){
                    $purchase->addMedia($file)->toMediaCollection('images');
                }
            }
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $purchase->addMedia($file)->toMediaCollection('attachments');
                }
            }
            $trans["trans_date"] = date('Y-m-d');
            $trans['creator_id']= auth()->user()->id;
            $trans["branche_id"] = auth()->user()->branche_id;
            if(isset($inputs['prod'])){
                foreach($inputs['prod'] as $i=>$item){

                    $product = Product::firstOrCreate(['id'=>$item['product_id'],'branche_id'=>$purchase->branche_id],['name'=>$item['product_id'],'cost'=>$item['price'],'price'=>$item['price'],'type'=>'قطع غيار']);
                    $productBranche = ProductBranche::query()
                        ->firstOrCreate(['product_id'=>$product->id,'branche_id'=>$purchase->branche_id],['product_id'=>$product->id,'branche_id'=>$purchase->branche_id,'qty'=>0]);
                    $productBranche->qty += $item['qty'];
                    $productBranche->save();
                    $inputs['prod'][$i]['product_id'] = $product->id;
                }
                $purchase->details()->attach($inputs['prod']);
            }
            DB::commit();
            return redirect(route('purchases.index'))->with('alert-success', 'تمت الإضافة بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $item = Purchase::withTrashed()->with(['details'])->find($id);
        $users = User::get();
        return view('purchases.show',compact('item','users'));
    }
    public function print($id)
    {
        $order = Purchase::withTrashed()->find($id);

        return view('purchases.print',compact('order'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Purchase $purchase)
    {

        $person =$purchase->supplier;
        return view('purchases.edit',['item'=>$purchase,'per'=>$person]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Purchase $purchase)
    {
        try{
            DB::beginTransaction();
            $productsOld = $purchase->details;
            if(!empty($productsOld)){
                foreach($productsOld as $prod){
                    if($prod->type == "قطع غيار"){
                        $productBranche = ProductBranche::query()
                        ->where('product_id',$prod->id)
                        ->where('branche_id',$purchase->branche_id)->first();
                        if($productBranche){
                            $productBranche->qty -= $prod->pivot->qty;
                            $productBranche->save();
                        }
                    }
                }
            }
            $inputs = $request->except('_token');
            $purchase->update($inputs['purchase']);

            if (isset($inputs['mediaTodelete'])) {
                Media::whereIn('id', $inputs['mediaTodelete'])->delete();
            }
            if($request->image){
                foreach ($request->image as $file){
                    $purchase->addMedia($file)->toMediaCollection('images');
                }
            }
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $purchase->addMedia($file)->toMediaCollection('attachments');
                }
            }
            $purchase->details()->detach();
            if(isset($inputs['prod'])){
                foreach($inputs['prod'] as $i=>$item){
                    $product = Product::firstOrCreate(['id'=>$item['product_id'],'branche_id'=>$purchase->branche_id],['name'=>$item['product_id'],'cost'=>$item['price'],'price'=>$item['price'],'type'=>'قطع غيار']);
                    if($product->type == "قطع غيار"){
                        $productBranche = ProductBranche::query()
                            ->firstOrCreate(['product_id'=>$product->id,'branche_id'=>$purchase->branche_id],['product_id'=>$product->id,'branche_id'=>$purchase->branche_id,'qty'=>0]);
                        $productBranche->qty += $item['qty'];
                        $productBranche->save();
                    }
                    $inputs['prod'][$i]['product_id'] = $product->id;
                }
                $purchase->details()->attach($inputs['prod']);
            }
            DB::commit();
            return redirect(route('purchases.index'))->with('alert-success', 'تم التعديل بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Purchase $purchase)
    {
        foreach($purchase->details as $prod){
            if(!is_null($prod->qty)){
                $productBranche = ProductBranche::query()
                        ->where('product_id',$prod->id)
                        ->where('branche_id',$purchase->branche_id)->first();
                $productBranche->qty -= $prod->pivot->qty;
                $productBranche->save();
            }
        }
        if($purchase->delete()){
            return "done";
        }
        return "failed";
    }


    public function addPayment(Request $request,$order_id){
        $order = Purchase::find($order_id);
        $person = Supplier::find($order->supplier_id);
        if($request->isMethod('post')){
            try{
                $inputs = $request->except('_token');
                $inputs['creator_id'] = auth()->user()->id;
                if(auth()->user()->branche_id){
                    $inputs['branche_id'] = auth()->user()->branche_id;
                }
                $inputs['value']= -$inputs['value'];
                $inputs['trans_type'] = 'صرف';
                $transaction =  $order->transactions()->create($inputs);
                if ($request->has('image')) {
                    $transaction->addMedia($request->file('image'))->toMediaCollection('images');
                }
                return redirect(route('transactions.show',$transaction))->with('alert-success', 'تمت الإضافة بنجاح');
            }catch(Exception $e){
                dd($e->getMessage());
            }
        }
        return view('purchases.payment',compact('person','order'));
    }
}
