<?php

namespace App\Http\Controllers;

use App\Models\Branche;
use App\Models\Client;
use App\Models\Department;
use App\Models\Returns;
use App\Models\ReturnsService;
use App\Models\Product;
use App\Models\ProductBranche;
use App\Models\ReturnDetail;
use App\Models\Status;
use App\Models\Type;
use App\Models\User;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;
use Yajra\DataTables\Facades\DataTables;

class ReturnsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        view()->composer(['returns._form','returns.show'],function($view){
            $view->with([
                'products'=>Product::get(),
                'statusList'=>Status::query()->get(),
                'typesList'=>Type::query()->get(),
            ]);
        });
        parent::__construct();
    }


    public function index(){
        if (\request()->ajax()) {
            $list = Returns::query()->with('items');
            $datatable = DataTables::of($list)
            ->addColumn('client',function($item){
                return '<a title="العميل" href="'.route('clients.show',$item->client_id).'" class="btn btn-success btn-xs">
                <i class="fa fa-user" aria-hidden="true"></i> '.optional($item->client)->name.'
                </a>';
            })

            ->addColumn('branche',function($item){
                return optional($item->branche)->name;
            })
            ->addColumn('post_date',function($item){
                return $item->post_date;
            })
            ->addColumn('creator',function($item){
                return optional($item->creator)->name;
            })
            ->addColumn('total',function($item){
                return $item->total;
            })
            ->addColumn('actions',function($item){
                $currentUser = auth()->user();
                $btn = '';
                $s = optional($item->currentStatus);
                if(($currentUser->can('Edit Returns') )){
                    $btn .= '<a  title = "تعديل" href = "'.route('returns.edit',$item).'" class="btn btn-primary btn-xs" >
                        <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                        </a >';
                }
                if($currentUser->can('addPayment Returns')){
                    $btn .= ' <a title="سند دفع" data-toggle="modal" data-target="#myModal" href="'.route('returns.addPayment',$item->id).'" class="btn btn-success btn-xs">
                    <i class="fa fa-money fa-fw" aria-hidden="true"></i>
                </a>';
                }
                if($currentUser->can('Show Returns')){
                    $btn .= ' <a title="التفاصيل" href="'.route('returns.show',$item).'" class="btn btn-warning btn-xs">
                                <i class="fa fa-pencil fa-eye" aria-hidden="true"></i>
                            </a>
                            <a title="طباعه" href="'.route('returns.print',$item).'" class="btn btn-info btn-xs">
                                <i class="fa fa-print" aria-hidden="true"></i>
                            </a>';
                }
                if($currentUser->can('Delete Returns')){
                    $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="'.route('returns.destroy',$item).'" data-id="'.$item->id.'">
                        <i class="fa fa-trash"></i>
                    </a>';
                }

                return $btn;
            });
            $datatable->rawColumns(['actions','client']);
            return $datatable->make(true);
        }
        return view('returns.index');
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('returns.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $inputs['invoice']['creator_id'] = auth()->user()->id;
            if(auth()->user()->branche_id){
                $inputs['invoice']['branche_id'] = auth()->user()->branche_id;
            }
            $invoice = Returns::create($inputs['invoice']);
            if($request->image){
                foreach ($request->image as $file){
                    $invoice->addMedia($file)->toMediaCollection('images');
                }
            }
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $invoice->addMedia($file)->toMediaCollection('attachments');
                }
            }
            if(isset($inputs['prod'])){
                // foreach($inputs['prod'] as $item){
                //     $productBranche = ProductBranche::query()
                //         ->where('product_id',$item['product_id'])
                //         ->where('branche_id',$invoice->branche_id)->first();
                //         $productBranche->qty -= $item['qty'];
                //         $productBranche->save();
                // }
                $invoice->details()->attach($inputs['prod']);
            }
            DB::commit();
            return redirect(route('returns.index'))->with('alert-success', 'تمت الإضافة بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $item = Returns::withTrashed()->with(['details'])->find($id);
        return view('returns.show',compact('item'));
    }
    public function print($id)
    {
        $order = Returns::withTrashed()->find($id);

        return view('returns.print',compact('order'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $invoice = Returns::find($id);
        $person =$invoice->client;
        return view('returns.edit',['item'=>$invoice,'per'=>$person]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        try{

            $invoice = Returns::find($id);
            DB::beginTransaction();
            $productsOld = $invoice->details;
            // if(!empty($productsOld)){
            //     foreach($productsOld as $prod){
            //         if($prod->type == "قطع غيار"){
            //             $productBranche = ProductBranche::query()
            //             ->where('product_id',$prod->id)
            //             ->where('branche_id',$invoice->branche_id)->first();
            //             if($productBranche){
            //                 $productBranche->qty += $prod->pivot->qty;
            //                 $productBranche->save();
            //             }
            //         }
            //     }
            // }
            $inputs = $request->except('_token');
            $invoice->update($inputs['invoice']);

            if (isset($inputs['mediaTodelete'])) {
                Media::whereIn('id', $inputs['mediaTodelete'])->delete();
            }
            if($request->image){
                foreach ($request->image as $file){
                    $invoice->addMedia($file)->toMediaCollection('images');
                }
            }
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $invoice->addMedia($file)->toMediaCollection('attachments');
                }
            }
            $invoice->details()->detach();
            if(isset($inputs['prod'])){
                // foreach($inputs['prod'] as $item){
                //     $product = Product::find($item['product_id']);
                //     if($product->type == "قطع غيار"){
                //         $productBranche = ProductBranche::query()
                //         ->where('product_id',$item['product_id'])
                //         ->where('branche_id',$invoice->branche_id)->first();
                //         if($productBranche){
                //             $productBranche->qty -= $item['qty'];
                //             $productBranche->save();
                //         }
                //     }
                // }
                $invoice->details()->attach($inputs['prod']);
            }
            DB::commit();
            return redirect(route('returns.index'))->with('alert-success', 'تم التعديل بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $invoice = Returns::find($id);
        foreach($invoice->details as $prod){
            if($prod->type == "قطع غيار"){
                $productBranche = ProductBranche::query()
                            ->where('product_id',$prod->id)
                            ->where('branche_id',$invoice->branche_id)->first();
                if($productBranche){
                    $productBranche->qty -= $prod->pivot->qty;
                    $productBranche->save();
                }
            }
        }
        if($invoice->delete()){
            return "done";
        }
        return "failed";
    }


    public function addPayment(Request $request,$order_id){
        $order = Returns::find($order_id);
        $person = Client::find($order->client_id);
        if($request->isMethod('post')){
            try{
                $inputs = $request->except('_token');
                $inputs['creator_id'] = auth()->user()->id;
                if(auth()->user()->branche_id){
                    $inputs['branche_id'] = auth()->user()->branche_id;
                }
                $inputs['value']= -$inputs['value'];
                $transaction =  $order->transactions()->create($inputs);
                if ($request->has('image')) {
                    $transaction->addMedia($request->file('image'))->toMediaCollection('images');
                }
                return redirect(route('transactions.show',$transaction))->with('alert-success', 'تمت الإضافة بنجاح');
            }catch(Exception $e){
                dd($e->getMessage());
            }
        }
        return view('returns.payment',compact('person','order'));
    }
    public function addStatus(Request $request,$order_id){
        $order = Returns::find($order_id);
        $order->status_id = $request->status_id;
        $order->save();
        $order->statusList()->attach([[
            'status_id'=>$request->status_id,
            'note'=>$request->note,
            'creator_id'=>auth()->user()->id,
            'creator_name'=>auth()->user()->name,
            'created_at'=>now()
        ]]);
        return back()->with('alert-success', 'تم تغير الحالة واضافة التعليق بنجاح');
    }


    public function qtyReview(Request $request){
        try{
            $data = $request->except('_token');
            $branche_id = $data['branche_id'];
            DB::beginTransaction();
            foreach($data['prod'] as $det){
                $detail = ReturnDetail::query()->where('id',$det['detail_id'])->first();
                $oldStaus = $detail->item_status;
                $detail->item_status = $det['item_status'];
                $detail->item_note = $det['item_note'];
                $detail->save();
                if($oldStaus=='تم الاستلام'){
                    continue;
                }
                if($det['item_status']=='تم الاستلام'){
                    $productBranche = ProductBranche::query()
                                        ->where('product_id',$det['product_id'])
                                        ->where('branche_id',$branche_id)->first();
                    if($productBranche){
                        $productBranche->qty += $det['qty'];
                        $productBranche->save();
                    }
                }
            }
            DB::commit();
        }catch(Exception $e){
            DB::rollBack();
            dd($e->getMessage());
        }
        return back()->with('alert-success', 'تم إستلام قطع الغيار بنجاح');
    }
}
