<?php
namespace App\Http\Controllers;

use App\Models\Role;
use Illuminate\Http\Request;
use App\Support\PermissionsTrait;
use Illuminate\Support\Arr;

class RolesController extends Controller
{
    use PermissionsTrait;

    public function __construct()
    {
        view()->composer('roles._form',function($view){

            $view->with('permissions',Arr::pluck($this->getPermissions(),'permission'));

        });

        $this->updatePermissionsTable();

        parent::__construct();
    }

    public function index()
    {
        $roles = Role::query()->paginate();

        return view('roles.index', compact('roles'));
    }

    public function create()
    {
        return view('roles.create', ['role' => new Role()]);
    }

    public function store(Request $request)
    {
        $this->validate($request,$this->getRoles());

        $data = $request->only('name');

        $role = Role::create($data);

        if($request->has('permissions')){

            $role->syncPermissions($request->get('permissions'));

        }

        return redirect()->route('roles.index')->with('alert-success', 'تمت الإضافة بنجاح');

    }

    public function edit($id)
    {
        return view('roles.edit', ['role' => Role::findOrFail($id)]);
    }

    public function update($id, Request $request)
    {
        $role = Role::findOrFail($id);

        $this->validate($request,$this->getRoles($role->id));

        $data = $request->only('name','restrict_ips');
        $data['restrict_ips'] = $request->restrict_ips?implode(',',$request->restrict_ips):'';
        $role->update($data);

        if($request->has('permissions')){

            $role->syncPermissions($request->get('permissions'));

        }
        return redirect()->route('roles.index')->with('alert-success', 'تم التعديل بنجاح');
    }

    public function destroy($id)
    {
        return Role::destroy($id);
    }

    public function getRoles($id=NULL)
    {
        return [
            'name'=>  $id ? 'required|unique:roles,name,'.$id : 'required|unique:roles' ,
            'permissions.*'=>'required|in:'.implode(',', Arr::pluck($this->getPermissions(),'permission'))

        ];
    }

}
