<?php

namespace App\Http\Controllers;

use App\Models\Supplier;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

use Yajra\DataTables\Facades\DataTables;

class SupplierController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function index(Request $req){
        if (\request()->ajax()) {
            $list = Supplier::query();
            // $branche = $req->branche_id?:auth()->user()->branche_id;
            // if($branche){
            //     $list->where(function($q)use($branche){
            //         $q->where('branche_id',$branche);
            //     });
            // }
            $datatable = DataTables::of($list)
                ->addColumn('actions',function($prod){
                    $currentUser = auth()->user();
                    $btn = '';

                    if($currentUser->can('Edit Suppliers')){
                        $btn .= ' <a data-toggle="modal" data-target="#myModal" title = "تعديل" href = "'.route('suppliers.edit',$prod).'" class="btn btn-primary btn-xs" >
                            <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                            </a >';
                    }
                    if($currentUser->can('Delete Suppliers')){
                        $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="'.route('suppliers.destroy',$prod).'" data-id="'.$prod->id.'">
                            <i class="fa fa-trash"></i>
                        </a>';
                    }

                    return $btn;
                });
            $datatable->rawColumns(['image','actions']);
            return $datatable->make(true);
        }
        return view('suppliers.index');
    }

    public function getSupplierList()
    {
        $list = Supplier::query();
        if(auth()->user()->branche_id){
            $list->where('branche_id',auth()->user()->branche_id);
        }
        $term = request('term');
        $results = array();
        if(!$term)  return response()->json($results);
        $list = $list->where('name', 'LIKE', '%'.$term.'%')->get();
        foreach ($list as $query)
        {
            $results[] = [ 'id' => $query->id, 'text' => $query->name];
        }
        return response()->json($results);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(\request()->ajax()){
            return view('suppliers.ajax');
        }else{
            return view('suppliers.create');
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            // if(auth()->user()->branche_id){
            //     $inputs['branche_id'] = auth()->user()->branche_id;
            // }
            if ($inputs['id_number']) {
                $search = Supplier::where('id_number', $inputs['id_number'])->first();
                if ($search) {
                    throw new \Exception('خطأ رقم الهوية مسجل مع شخص أخر وهو ' . $search->name);
                }
            }
            $supplier = Supplier::create($inputs);
            if($request->attachments){
                foreach ($request->attachments as $file){
                    $supplier->addMedia($file)->toMediaCollection('attachments');
                }
            }
            DB::commit();
            if(request()->reqType=='ajax'){
                $suppliers = Supplier::query()->get();
                return view('suppliers.dropdown',compact('suppliers'));
            }
            return back()->with('alert-success', 'تمت الإضافة بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
           return back()->with('alert-danger',$e->getMessage());
            //dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $supplier = Supplier::filter()->find($id);
        return view('suppliers.show',compact('supplier'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Supplier $supplier)
    {
        return view('suppliers.edit',['supplier'=>$supplier]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Supplier $supplier)
    {
        $inputs = $request->except('_token');
        $supplier->update($inputs);

        if (isset($inputs['mediaTodelete'])) {
            Media::whereIn('id', $inputs['mediaTodelete'])->delete();
        }
        if($request->attachments){
            foreach ($request->attachments as $file){
                $supplier->addMedia($file)->toMediaCollection('attachments');
            }
        }
        return back()->with('alert-success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Supplier $supplier)
    {
        if($supplier->delete()){
            return "done";
        }
        return "failed";
    }

    public function getSuppliersList()
    {
        $term = request('term');
        $results = array();
        $queries = Supplier::query();
        if($term){
            $queries->whereRaw('LOWER(name) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(mobile) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(id_number) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(model) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(chassis_no) like "%'.strtolower($term).'%"');
            $queries->orwhereRaw('LOWER(car_number) like "%'.strtolower($term).'%"');
        }
        $queries = $queries->take(20)->get();
        foreach ($queries as $query) {
            $results[] = ['id' => $query->id, 'text' => $query->id. " - ".$query->name. " - ".$query->mobile. " - ".$query->model];
        }
        return response()->json($results);
    }

}
