<?php

namespace App\Http\Controllers;

use App\Models\Branche;
use App\Models\Client;
use App\Models\Invoice;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;

use Yajra\DataTables\Facades\DataTables;

class TransactionsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function __construct()
    {
        view()->composer(['_partial.transactions_filter'],function($view){
            $users = User::query();
            $persons = Client::query();
            $branches = Branche::query();
            $userBrancheId = auth()->user()->branche_id;
            if($userBrancheId){
                $users->where('branche_id',$userBrancheId);
                $persons->where('branche_id',$userBrancheId);
                $branches->where('id',$userBrancheId);
            }
            $users = $users->get();
            $persons = $persons->get();
            $branches = $branches->get();
            $view->with([
                'users'=>$users,
                'persons'=>$persons,
                'branches'=>$branches,
            ]);
        });
        parent::__construct();
    }
    public function index(Request $req){
        if (\request()->ajax()) {
            $list = Transaction::query()->filter();
            $branche = $req->branche_id?:auth()->user()->branche_id;
            if($branche){
                $list->where(function($q)use($branche){
                    $q->where('branche_id',$branche);
                });
            }
            $datatable = DataTables::of($list)
                ->addColumn('image',function($trans){
                    $img = optional($trans->getFirstMedia('images'))->getUrl();
                    if($img){
                        return '<img style="width: 80px;" src="'.$img.'" />';
                    }
                })
                ->addColumn('username',function($trans){
                    return optional($trans->creator)->name;
                })
                ->addColumn('branchename',function($trans){
                    return optional($trans->branche)->name;
                })
                ->addColumn('value',function($trans){
                    return number_format(abs($trans->value));
                })
                ->addColumn('time',function($trans){
                    return $trans->time_ar;
                })
                ->addColumn('actions',function($trans){
                    $currentUser = auth()->user();
                    $btn = '';

                    if($currentUser->can('Edit Transactions')){
                        $btn .= ' <a data-toggle="modal" data-target="#myModal" title = "تعديل" href = "'.route('transactions.edit',$trans).'" class="btn btn-primary btn-xs" >
                            <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i >
                            </a >';
                    }
                    if($currentUser->can('Delete Transactions')){
                        $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="'.route('transactions.destroy',$trans).'" data-id="'.$trans->id.'">
                            <i class="fa fa-trash"></i>
                        </a>';
                    }
                    if($currentUser->can('Show Transactions')){
                        $btn .= ' <a title="طباعه" href="'.route('transactions.show',$trans).'" class="btn btn-info btn-xs">
                        <i class="fa fa-print" aria-hidden="true"></i>
                        </a>';
                    }

                    return $btn;
                });
            $datatable->rawColumns(['image','actions']);
            $totalOrder = clone $list;
            $totalWithdraw = clone $list;
            $totalOrder = $totalOrder->where('trans_type','قبض')->select(
                DB::raw('Sum(ABS(value)) as totalVal')
            )->first();
            $totalWithdraw = $totalWithdraw->where('trans_type','صرف')->select(
                DB::raw('SUM(ABS(value)) as totalVal')
            )->first();
            $totalVal = $totalOrder->totalVal??0;
            $totalWithdraw = $totalWithdraw->totalVal??0;
            $datatable = $datatable->with('totalOrder',number_format($totalVal));
            $datatable = $datatable->with('totalProfit',number_format($totalWithdraw));
            return $datatable->make(true);
        }
        return view('transactions.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('transactions.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $inputs['creator_id'] = auth()->user()->id;
            if(auth()->user()->branche_id){
                $inputs['branche_id'] = auth()->user()->branche_id;
            }
            $inputs['model_type'] = Transaction::class;
            $inputs['value']= -$inputs['value'];
            $transaction = Transaction::create($inputs);
            if ($request->has('image')) {
                $transaction->addMedia($request->file('image'))->toMediaCollection('images');
            }
            DB::commit();
            return back()->with('alert-success', 'تمت الإضافة بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
           return back()->with('alert-danger',$e->getMessage());
            //dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $transaction = Transaction::find($id);
        return view('transactions.show',compact('transaction'));
    }



    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Transaction $transaction)
    {
        return view('transactions.edit',['transaction'=>$transaction]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Transaction $transaction)
    {
        $inputs = $request->except('_token');

        $inputs['value']= -$inputs['value'];
        $transaction->update($inputs);

        if (isset($inputs['mediaTodelete'])) {
            Media::whereIn('id', $inputs['mediaTodelete'])->delete();
        }
        if ($request->has('image')) {
            $transaction->addMedia($request->file('image'))->toMediaCollection('images');
        }
        return back()->with('alert-success', 'تم التعديل بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Transaction $transaction)
    {
        if($transaction->delete()){
            return "done";
        }
        return "failed";
    }

}
