<?php
namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class UsersController extends Controller
{

    public function index()
    {
        $users = User::get();

        return view('users.index',compact('users'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = new User;
        return view('users.create',compact('user'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try{
            DB::beginTransaction();
            $inputs = $request->except('_token');
            if($inputs['password']){
                $inputs['password'] = bcrypt($inputs['password']);
            }
            $user = User::create($inputs);
            $user->assignRole($inputs['role']);
            if($request->hasFile('photo')) {
                $user->addMedia($request->file('photo'))->toMediaCollection('photo');
            }

            if(isset($inputs['branches']) && $inputs['branches']){
                $user->branches()->attach($inputs['branches']);
            }
            if(isset($inputs['department_id']) && !empty($inputs['department_id'])){
                $user->department()->attach($inputs['department_id']);
            }
            DB::commit();
            return redirect(route('users.index'))->with('alert-success', 'تمت الإضافة بنجاح');
        }catch (\Exception $e){
            DB::rollBack();
           // dd($e->getMessage());
            return back()->with('alert-danger', 'حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة');

        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::findOrFail($id);
        return view('users.show',compact('user'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {
        return view('users.edit',compact('user'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, User $user)
    {
        $inputs = $request->except('_token');
        if($inputs['password']){
            $inputs['password'] = bcrypt($request->password);
        }else{
            $inputs['password'] = $user->password;
        }
        $user->update($inputs);
        $user->department()->detach();
        if(isset($inputs['department_id']) && !empty($inputs['department_id'])){
            $user->department()->attach($inputs['department_id']);
        }
        $user->syncRoles($inputs['role']);
        if($request->hasFile('photo')) {
            $user->media()->delete();
            $user->addMedia($request->file('photo'))->toMediaCollection('photo');
        }
        return redirect(route('users.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        if($user->delete()){
            return "done";
        }
        return "failed";
    }


}
