<?php

namespace App\Http\Controllers;

use App\Models\Branche;
use App\Models\Client;
use App\Models\Department;
use App\Models\Invoice;
use App\Models\WorkOrder;
use App\Models\Product;
use App\Models\Status;
use App\Models\User;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\Models\Media;
use Yajra\DataTables\Facades\DataTables;

class WorkOrdersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        view()->composer('workorders._form', function ($view) {
            $view->with([
                'products' => Product::get(),
                'persons' => Client::get()
            ]);
        });
        view()->composer(['_partial.workorderfilter'], function ($view) {
            $users = User::query();
            $persons = Client::query();
            $branches = Branche::query();
            $userBrancheId = auth()->user()->branche_id;
            if ($userBrancheId) {
                $users->where('branche_id', $userBrancheId);
                $persons->where('branche_id', $userBrancheId);
                $branches->where('id', $userBrancheId);
            }
            $users = $users->get();
            $persons = $persons->get();
            $branches = $branches->get();
            $view->with([
                'users' => $users,
                'persons' => $persons,
                'branches' => $branches,
            ]);
        });
        parent::__construct();
    }


    public function index()
    {
        if (\request()->ajax()) {
            $list = WorkOrder::query()->with('client')->filter();
            $datatable = DataTables::of($list)
                ->addColumn('client', function ($item) {
                    return '<a title="العميل" href="' . route('clients.show', $item->client_id) . '" class="btn btn-success btn-xs">
                <i class="fa fa-user" aria-hidden="true"></i> ' . optional($item->client)->name . '
                </a>';
                })

                ->addColumn('model', function ($item) {
                    return optional($item->client)->model;
                })
                ->addColumn('mobile', function ($item) {
                    return optional($item->client)->mobile;
                })

                ->addColumn('id_number', function ($item) {
                    return optional($item->client)->model;
                })
                ->addColumn('chassis_no', function ($item) {
                    return optional($item->client)->chassis_no;
                })
                ->addColumn('car_number', function ($item) {
                    return optional($item->client)->car_number;
                })
                ->addColumn('branche', function ($item) {
                    return optional($item->branche)->name;
                })
                ->addColumn('entery', function ($item) {
                    return $item->getDateAr($item->entery_at);
                })
                ->addColumn('exit', function ($item) {
                    return $item->getDateAr($item->exit_at);
                })
                ->addColumn('creator', function ($item) {
                    return optional($item->creator)->name;
                })
                ->addColumn('actions', function ($item) {
                    $currentUser = auth()->user();
                    $btn = '';

                    if ($currentUser->can('Edit WorkOrders')) {
                        $btn .= '<a  title = "تعديل" href = "' . route('workorders.edit', $item) . '" class="btn btn-primary btn-xs" >
                        <i class="fa fa-pencil fa-fw" aria-hidden = "true" ></i> تعديل
                        </a >';
                    }

                    if (!$item->order_id && $currentUser->can('makeinvoice WorkOrders')) {
                        $btn .= ' <form method="post" action="' . route('workorders.makeinvoice', $item->id) . '">
                        ' . csrf_field() . '
                        <button title="اضافة فاتورة" type="submit" class="btn btn-xs btn-warning"><i class="fa fa-file"></i> فاتورة</button>
                    </form>';
                    }
                    if ($currentUser->can('Show WorkOrders')) {
                        $btn .= ' <a title="طباعه" href="' . route('workorders.show', $item) . '" class="btn btn-info btn-xs">
                                <i class="fa fa-print" aria-hidden="true"></i> طباعه
                            </a>';
                    }
                    if ($currentUser->can('Delete WorkOrders')) {
                        $btn .= ' <a title="حذف" class="btn btn-xs btn-danger remove-record" data-url="' . route('workorders.destroy', $item) . '" data-id="' . $item->id . '">
                        <i class="fa fa-trash"></i> حذف
                    </a>';
                    }

                    return $btn;
                });
            $datatable->rawColumns(['actions', 'client']);
            return $datatable->make(true);
        }
        return view('workorders.index');
    }
    public function MakeInvoice($id)
    {
        DB::beginTransaction();
        try {
            $ordertask = WorkOrder::find($id);
            $orderData = [
                'client_id' => $ordertask->client_id,
                'car_id' => $ordertask->car_id,
                'creator_id' => auth()->user()->id,
                'branche_id' => $ordertask->branche_id,
                'entery_at' => $ordertask->entery_at,
                'exit_at' => $ordertask->exit_at,
                'kilo_counter' => $ordertask->kilo_counter,
                'note' => $ordertask->note,
                'total' => 0,
                'paid' => 0,
                'due' => 0,
                'date' => date('Y-m-d'),
                'status_id' => Status::query()->first()->id,
                'payment' => 'كاش'
            ];
            $order = Invoice::create($orderData);
            $order->addInvoiceTask($order);
            $ordertask->order_id = $order->id;
            $ordertask->save();

            DB::commit();
            $route = route('invoices.edit', $order->id);
            return redirect($route)->with('alert-success', 'تمت الاضافة بنجاح');
        } catch (\Exception $e) {
            DB::rollBack();
            // return back()->with('alert-danger','خطأ !! '.$e->getMessage());
            dd($e->getMessage());
        }
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('workorders.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            DB::beginTransaction();
            $inputs = $request->except('_token');
            $inputs['invoice']['creator_id'] = auth()->user()->id;
            if (auth()->user()->branche_id) {
                $inputs['invoice']['branche_id'] = auth()->user()->branche_id;
            }
            $invoice = WorkOrder::create($inputs['invoice']);
            if ($request->image) {
                foreach ($request->image as $file) {
                    $invoice->addMedia($file)->toMediaCollection('images');
                }
            }
            if ($request->attachments) {
                foreach ($request->attachments as $file) {
                    $invoice->addMedia($file)->toMediaCollection('attachments');
                }
            }
            DB::commit();
            return redirect(route('workorders.index'))->with('alert-success', 'تمت الإضافة بنجاح');
        } catch (\Exception $e) {
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $order = WorkOrder::find($id);
        return view('workorders.print', compact('order'));
    }




    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(WorkOrder $workorder)
    {

        $person = $workorder->client;
        return view('workorders.edit', ['item' => $workorder, 'per' => $person]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        try {
            DB::beginTransaction();
            $invoice = WorkOrder::find($id);
            $productsOld = $invoice->details;
            if (!empty($productsOld)) {
                foreach ($productsOld as $prod) {
                    if (!is_null($prod->qty) && $invoice->type == "قطع غيار") {
                        $prod->qty += $prod->pivot->qty;
                        $prod->save();
                    }
                }
            }
            $inputs = $request->except('_token');
            $invoice->update($inputs['invoice']);
            if (isset($inputs['mediaTodelete'])) {
                Media::whereIn('id', $inputs['mediaTodelete'])->delete();
            }
            if ($request->image) {
                foreach ($request->image as $file) {
                    $invoice->addMedia($file)->toMediaCollection('images');
                }
            }
            if ($request->attachments) {
                foreach ($request->attachments as $file) {
                    $invoice->addMedia($file)->toMediaCollection('attachments');
                }
            }
            DB::commit();
            return redirect(route('workorders.index'))->with('alert-success', 'تم التعديل بنجاح');
        } catch (\Exception $e) {
            DB::rollBack();
            return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة ' . $e->getMessage());
            dd($e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(WorkOrder $workorder)
    {
        if ($workorder->delete()) {
            return "done";
        }
        return "failed";
    }

}