<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;

class Detail extends Model
{
    protected $table = 'details';
    protected $fillable = ['invoice_id','product_id','qty','price','cost','discount','profit','item_status','item_note'];

    public function invoice(){
        return $this->belongsTo(Invoice::class);
    }
    public function car(){
        return $this->belongsTo(Car::class);
    }
    public function instalment(){
        return $this->hasManyThrough(Installment::class,Invoice::class,'id','invoice_id','invoice_id','id');
    }
    public function scopeFilter(Builder $builder){
        $from = request('fromdate');
        $to = request('todate');

        $builder->whereHas('instalment',function ($q)use($from,$to){
            $q->whereRaw('value > paid_value');
            if (!empty($from)) {
                $q->whereRaw("DATE(installments.date) >= '{$from}'");
            }
            if (!empty($to)) {
                $q->whereRaw("DATE(installments.date) <= '{$to}'");
            }
        });
        $builder->with([
            'instalment'=>function($q)use($from,$to){
                $q->whereRaw('value > paid_value');
                if (!empty($from)) {
                    $q->whereRaw("DATE(installments.date) >= '{$from}'");
                }
                if (!empty($to)) {
                    $q->whereRaw("DATE(installments.date) <= '{$to}'");
                }
            },
            'car']);
        return $builder->get();
    }
    public function scopeSearch(Builder $builder,$type){
        $from = request('fromdate');
        $to = request('todate');
        $user_id = request('user_id');
        $client_id = request('client_id');
        $payment = request('payment');
        $sales_id = request('sales_id');
        $funder_id = request('funder_id');
        $car_id = request('car_id');
        if($car_id){
            $builder->where('car_id',$car_id);
        }

        $branche = request('branche_id')?:auth()->user()->branche_id;
        // if(isset(request('search')['value']) && !empty(request('search')['value'])){
        //     $searchVal = request('search')['value'];
        //     $builder->orwhereHas('car',function($qry)use($searchVal){
        //         $qry->where('chassis_no','like',"%".$searchVal."%")
        //         ->orwhere('car_number','like',"%".$searchVal."%");
        //     });
        // }
        $builder->whereHas('invoice',function($qry)use($funder_id,$branche,$from,$to,$type,$user_id,$client_id,$payment,$sales_id){
            $qry->where('type',$type);
            if($funder_id){
                $qry->whereHas('finance',function($q)use($funder_id){
                    $q->where('funder_id',$funder_id);
                });
            }
            if($branche){
                $qry->where('branche_id',$branche);
            }
            if($payment){
                $qry->where('payment',$payment);
            }
            if($sales_id){
                $qry->where('sales_id',$sales_id);
            }
            if (!empty($from)) {
                $qry->whereRaw("DATE(date) >= '{$from}'");
            }
            if (!empty($to)) {
                $qry->whereRaw("DATE(date) <= '{$to}'");
            }
            if($user_id){
                $qry->where('creator_id',$user_id);
            }
            if($client_id){
                $qry->where('person_id',$client_id);
            }

        });
        $builder->with([

            'invoice'=>function($qry)use($funder_id,$branche,$from,$to,$type,$user_id,$payment,$sales_id){
                $qry->where('type',$type);
                if($branche){
                    $qry->where('branche_id',$branche);
                }
                if($funder_id){
                    $qry->whereHas('finance',function($q)use($funder_id){
                        $q->where('funder_id',$funder_id);
                    });
                }
                if($payment){
                    $qry->where('payment',$payment);
                }
                if($sales_id){
                    $qry->where('sales_id',$sales_id);
                }
                if (!empty($from)) {
                    $qry->whereRaw("DATE(date) >= '{$from}'");
                }
                if (!empty($to)) {
                    $qry->whereRaw("DATE(date) <= '{$to}'");
                }
                if($user_id){
                    $qry->where('creator_id',$user_id);
                }
            },'car']);
            $builder->orderBy('id','DESC');
        return $builder;
    }
}
