<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Spatie\MediaLibrary\HasMedia\HasMedia;
use Spatie\MediaLibrary\HasMedia\HasMediaTrait;

class OrderTask extends Model implements HasMedia
{
    use HasMediaTrait;

    protected $table = 'order_task';

    public $fillable = [
        'order_id','client_id','department_id',
        'mission_id','must_completed','user_id','start',
        'status','note','notifcation_date','branche_id','car_id','action_at'
    ];

    public function order(){
        return $this->belongsTo(Invoice::class,'order_id','id');
    }

    public function branche(){
        return $this->belongsTo(Branche::class,'branche_id','id');
    }

    public function client(){
        return $this->belongsTo(Client::class,'client_id','id');
    }

    public function task(){
        return $this->belongsTo(Mission::class,'mission_id','id');
    }

    public function department(){
        return $this->belongsTo(Department::class);
    }

    public function user(){
        return $this->belongsTo(User::class,'user_id','id');
    }

    public function scopeFilter(Builder $builder)
    {
        $builder->with(['client','order','task','department']);
        $from = request('start_date');
        $to = request('end_date');
        $user_id = request('user_id');
        $department_id = request('department_id');
        $client_id = request('client_id');
        $task_id = request('task_id');
        $status = request('status');

        if($user_id) {
            $builder->where('user_id', $user_id);
        }
        if($department_id) {
            $builder->where('department_id', $department_id);
        }
        if($client_id) {
            $builder->where('client_id', $client_id);
        }
        if($task_id) {
            $builder->where('task_id', $task_id);
        }
        if($status) {
            $builder->where('status', $status);
        }
        if (!empty($from)){
            $builder->whereRaw("DATE(notifcation_date) >= '{$from}'");
        }
        if (!empty($to)) {
            $builder->whereRaw("DATE(notifcation_date) <= '{$to}'");
        }
        return $builder->orderBy('id');
    }
}
