<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Model;
use Spatie\MediaLibrary\HasMedia\HasMedia;
use Spatie\MediaLibrary\HasMedia\HasMediaTrait;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Facades\DB;

class Product extends Model implements HasMedia
{
    use HasMediaTrait;
    protected $fillable = [
        'name','qty','cost','price','branche_id',
        'type','code','location','notify_limit',
        'description','model','tax'
    ];

    public function productBranche(){
        return $this->belongsToMany(Branche::class,'product_branche','product_id','branche_id')
            ->withPivot(['location','qty'])
            ->where('branche_id',auth()->user()->branche_id)
            ->withTimestamps();
    }

    public function getCurrentQtyAttribute()
    {
        $productBranches = $this->productBranche()->where('branche_id',auth()->user()->branche_id)->first();
        return $productBranches->pivot->qty??0;
    }


    public function branches(){
        return $this->belongsToMany(Branche::class,'product_branche','product_id','branche_id')
            ->withPivot(['location','qty'])
            ->withTimestamps();
    }


    public function order(){
        return $this->belongsToMany(Invoice::class,'details','product_id','invoice_id');
    }
    public function scopeFilter(Builder $builder){
        $type = request('type');
        $limit = request('limit');
        $from = request('fromdate');
        $to = request('todate');
        $branche = request('branche_id');

        if($type){
            $builder->where('type',$type);
        }
        if($limit){
            $builder->where('type','قطع غيار');
            if($limit=="قطع الغيار الناقصه"){
                $builder->whereHas('branches',function($q){
                    $q->whereRaw('product_branche.qty <= products.notify_limit');
                });
            }else{
                $builder->whereHas('branches',function($q){
                    $q->whereRaw(DB::raw('product_branche.qty > products.notify_limit'));
                });
            }
        }
        if($branche){
            $builder->where('branche_id',$branche);
        }
        if (!empty($from) || !empty($to)){
            $builder->whereHas('order',function($query) use($from,$to){
                if (!empty($from)) {
                    $query->whereRaw("DATE(date) >= '{$from}'");
                }
                if (!empty($to)) {
                    $query->whereRaw("DATE(date) <= '{$to}'");
                }
            });
        }

        return $builder;
    }
}
