<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia\HasMedia;
use Spatie\MediaLibrary\HasMedia\HasMediaTrait;

class Purchase extends Model implements HasMedia
{
    use HasMediaTrait, SoftDeletes;
    protected $fillable = [
        'payment',
        'date',
        'supplier_id',
        'total',
        'paid',
        'due',
        'note',
        'creator_id',
        'branche_id',
        'status',
        'tax',
        'shipping',
        'fees',
        'supplier_invoice_num'
    ];
    protected $with = ['details'];

    public function details()
    {
        return $this->belongsToMany(Product::class, 'purchase_details', 'purchase_id', 'product_id')
            ->withPivot(['price', 'cost', 'qty', 'discount']);
    }


    public function supplier()
    {
        return $this->belongsTo(Supplier::class)->withTrashed();
    }
    public function creator()
    {
        return $this->belongsTo(User::class, 'creator_id', 'id');
    }

    public function branche()
    {
        return $this->belongsTo(Branche::class, 'branche_id', 'id');
    }

    public function transactions()
    {
        return $this->morphMany(Transaction::class, 'transactionable', 'model_type', 'model_id');
    }

    public function getTotalDueAttribute()
    {
        $total = $this->total;
        $paid = $this->total_paid;
        return floor($total - $paid);
    }

    public function getTotalPaidAttribute()
    {
        $total_paid = floor($this->transactions()->sum('value') + $this->paid);
        return abs($total_paid);
    }

    public function scopeFilter(Builder $builder)
    {
        $from = request('start_date');
        $to = request('end_date');
        $user_id = request('user_id');
        $client_id = request('client_id');
        $entery_at = request('entery_at');
        $exit_at = request('exit_at');
        $status = request('status');
        $type = request('type');
        $branche = request('branche_id') ?: auth()->user()->branche_id;
        if ($status) {
            $builder->where('status_id', $status);
        }
        if ($type) {
            $builder->where('type_id', $type);
        }
        if ($branche) {
            $builder->where('branche_id', $branche);
        }
        if ($client_id) {
            $builder->where('client_id', $client_id);
        }
        if ($user_id) {
            $builder->where('creator_id', $user_id);
        }
        if (!empty($entery_at)) {
            $builder->whereRaw("DATE(entery_at) = '{$entery_at}'");
        }
        if (!empty($exit_at)) {
            $builder->whereRaw("DATE(exit_at) = '{$exit_at}'");
        }
        if (!empty($from)) {
            $builder->whereRaw("DATE(date) >= '{$from}'");
        }
        if (!empty($to)) {
            $builder->whereRaw("DATE(date) <= '{$to}'");
        }
        return $builder->latest();
    }

    public function getTotalAttribute($val)
    {
        return floor($val);
    }
    public function getPaidAttribute($val)
    {
        return floor($val);
    }
    public function getDueAttribute($val)
    {
        return floor($val);
    }
    public function getPostDateAttribute()
    {
        $months = array("Jan" => "يناير", "Feb" => "فبراير", "Mar" => "مارس", "Apr" => "أبريل", "May" => "مايو", "Jun" => "يونيو", "Jul" => "يوليو", "Aug" => "أغسطس", "Sep" => "سبتمبر", "Oct" => "أكتوبر", "Nov" => "نوفمبر", "Dec" => "ديسمبر");
        //$your_date = $this->created_at->addDays(1)->format('Y-m-d');    //date('y-m-d'); // The Current Date
        if (!$this->date)
            return "";
        $your_date = $this->date;
        // if(app()->getLocale()=='en'){
        //     return date('l, d F Y',strtotime($your_date));
        // }
        $en_month = date("M", strtotime($your_date));
        foreach ($months as $en => $ar) {
            if ($en == $en_month) {
                $ar_month = $ar;
            }
        }
        $find = array("Sat", "Sun", "Mon", "Tue", "Wed", "Thu", "Fri");
        $replace = array("السبت", "الأحد", "الإثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة");
        $ar_day_format = date("D", strtotime($your_date)); //date('D'); // The Current Day
        $ar_day = str_replace($find, $replace, $ar_day_format);
        $day_num = date("d", strtotime($your_date));
        $year_num = date("Y", strtotime($your_date));
        header('Content-Type: text/html; charset=utf-8');
        $standard = array("0", "1", "2", "3", "4", "5", "6", "7", "8", "9");
        $eastern_arabic_symbols = array("٠", "١", "٢", "٣", "٤", "٥", "٦", "٧", "٨", "٩");
        $current_date = $ar_day . ', ' . $day_num . ' ' . $ar_month . ' ' . $year_num;
        $arabic_date = str_replace($standard, $eastern_arabic_symbols, $current_date);

        return $arabic_date;
    }
}