<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia\HasMedia;
use Spatie\MediaLibrary\HasMedia\HasMediaTrait;

class Transaction extends Model  implements HasMedia
{
    use HasMediaTrait,SoftDeletes;

    public static $Intrans = [
        'مبيعات','مدفوعات عملاء'
    ];
    public static $outtrans = [
       'مشتريات','مصروفات','مدفوعات موردين'
    ];

    protected $fillable = [
        'value','note','trans_date',
        'creator_id','branche_id','trans_type'
    ];

    public function model()
    {
        return $this->morphTo();
    }

    public function creator(){
        return $this->belongsTo(User::class,'creator_id','id');
    }
    public function branche(){
        return $this->belongsTo(Branche::class,'branche_id','id');
    }

    public function scopeFilter(Builder $builder){
        $from = request('fromdate');
        $to = request('todate');
        $creator_id = request('creator_id');
        $branche_id = request('branche_id');
        $trans_type = request('trans_type');
        if($creator_id){
            $builder->where('creator_id',$creator_id);
        }
        if($branche_id){
            $builder->where('branche_id',$branche_id);
        }
        if($trans_type){
            $builder->where('trans_type',$trans_type);
        }
        if (!empty($from)) {
            $builder->whereRaw("DATE(trans_date) >= '{$from}'");
        }
        if (!empty($to)) {
            $builder->whereRaw("DATE(trans_date) <= '{$to}'");
        }
        return $builder;
    }
    public function getTimeArAttribute() {
        $curDT = $this->created_at;
        //dd($curDT->format('Y-m-d h:i a'));
        $curTime = strtotime($curDT);
        $arrEn = array('am', 'pm');
        $arrAr = array('صباحاً', 'مساءً');
        $newformat =  date("h:i ",$curTime).str_replace($arrEn, $arrAr,date("a", $curTime));
        return $newformat;
    }
    public function getDateArAttribute() {


        $months = array("Jan" => "يناير", "Feb" => "فبراير", "Mar" => "مارس", "Apr" => "أبريل", "May" => "مايو", "Jun" => "يونيو", "Jul" => "يوليو", "Aug" => "أغسطس", "Sep" => "سبتمبر", "Oct" => "أكتوبر", "Nov" => "نوفمبر", "Dec" => "ديسمبر");
        if(!$this->trans_date) return "";
        $your_date = $this->trans_date;
        $en_month = date("M", strtotime($your_date));
        foreach ($months as $en => $ar) {
            if ($en == $en_month) { $ar_month = $ar; }
        }
        $find = array ("Sat", "Sun", "Mon", "Tue", "Wed" , "Thu", "Fri");
        $replace = array ("السبت", "الأحد", "الإثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة");
        $ar_day_format = date("D", strtotime($your_date)); //date('D'); // The Current Day
        $ar_day = str_replace($find, $replace, $ar_day_format);
        $day_num = date("d", strtotime($your_date));
        $year_num = date("Y", strtotime($your_date));
        header('Content-Type: text/html; charset=utf-8');
        $standard = array("0","1","2","3","4","5","6","7","8","9");
        $eastern_arabic_symbols = array("٠","١","٢","٣","٤","٥","٦","٧","٨","٩");
        $current_date = $ar_day.', '.$day_num.' '.$ar_month.' '.$year_num;
        $arabic_date = str_replace($standard , $eastern_arabic_symbols , $current_date);

        return $arabic_date;
    }
}
