<?php

namespace App\Models;

use App\Support\PermissionPoliciesTrait;
use App\Support\PermissionsTrait;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Spatie\MediaLibrary\HasMedia\HasMedia;
use Spatie\MediaLibrary\HasMedia\HasMediaTrait;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable implements HasMedia
{
    use Notifiable,HasMediaTrait,HasRoles,PermissionsTrait,PermissionPoliciesTrait;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password','branche_id'
    ];

    protected $appends = ['role_name'];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];


    // public function branches(){
    //     return $this->belongsToMany(Branche::class,'user_branches','user_id','branche_id')
    //         ->withTimestamps();
    // }
    public function getroleNameAttribute(){
        return optional($this->roles())->first()->name;
    }
    public function branche(){
        return $this->belongsTo(Branche::class);
    }


    public function department(){
        return $this->belongsToMany(Department::class,'user_department','user_id','department_id');
    }

    public function getdepIdAttribute(){
        return $this->department()->pluck('department_id')->toArray();
    }
    public function getdepNameAttribute(){
        $list = $this->department()->pluck('name')->toArray();
        return $list?implode(', ',$list):'غير محدد';
    }
}
