<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia\HasMedia;
use Spatie\MediaLibrary\HasMedia\HasMediaTrait;

class WorkOrder extends Model implements HasMedia
{
    use HasMediaTrait;
    protected $table = "workorders";
    protected $fillable = [
        'client_id',
        'note',
        'creator_id',
        'branche_id',
        'entery_at',
        'exit_at',
        'kilo_counter',
        'name',
        'car_id'
    ];

    public function car()
    {
        return $this->belongsTo(ClientCar::class, 'car_id', 'id');
    }
    public function setEnteryAtAttribute($value)
    {
        $this->attributes['entery_at'] = Carbon::parse($value);
    }

    public function setExitAtAttribute($value)
    {
        $this->attributes['exit_at'] = $value ? Carbon::parse($value) : null;
    }

    public function client()
    {
        return $this->belongsTo(Client::class)->withTrashed();
    }
    public function creator()
    {
        return $this->belongsTo(User::class, 'creator_id', 'id');
    }

    public function branche()
    {
        return $this->belongsTo(Branche::class, 'branche_id', 'id');
    }


    public function scopeFilter(Builder $builder)
    {
        $from = request('start_date');
        $to = request('end_date');
        $user_id = request('user_id');
        $client_id = request('client_id');
        $entery_at = request('entery_at');
        $exit_at = request('exit_at');
        $status = request('status');
        $branche = request('branche_id') ?: auth()->user()->branche_id;
        if ($status) {
            $builder->where('status', $status);
        }

        if ($branche) {
            $builder->where('branche_id', $branche);
        }
        if ($client_id) {
            $builder->where('client_id', $client_id);
        }
        if ($user_id) {
            $builder->where('creator_id', $user_id);
        }
        if (!empty($entery_at)) {
            $builder->whereRaw("DATE(entery_at) = '{$entery_at}'");
        }
        if (!empty($exit_at)) {
            $builder->whereRaw("DATE(exit_at) = '{$exit_at}'");
        }
        return $builder->latest();
    }

    public function getDateAr($your_date)
    {
        $months = array("Jan" => "يناير", "Feb" => "فبراير", "Mar" => "مارس", "Apr" => "أبريل", "May" => "مايو", "Jun" => "يونيو", "Jul" => "يوليو", "Aug" => "أغسطس", "Sep" => "سبتمبر", "Oct" => "أكتوبر", "Nov" => "نوفمبر", "Dec" => "ديسمبر");
        if (!$your_date)
            return "";
        $en_month = date("M", strtotime($your_date));
        $curTime = strtotime($your_date);
        $arrEn = array('am', 'pm');
        $arrAr = array('صباحاً', 'مساءً');
        $newTimeFormat = date("h:i ", $curTime) . str_replace($arrEn, $arrAr, date("a", $curTime));

        foreach ($months as $en => $ar) {
            if ($en == $en_month) {
                $ar_month = $ar;
            }
        }
        $find = array("Sat", "Sun", "Mon", "Tue", "Wed", "Thu", "Fri");
        $replace = array("السبت", "الأحد", "الإثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة");
        $ar_day_format = date("D", strtotime($your_date)); //date('D'); // The Current Day
        $ar_day = str_replace($find, $replace, $ar_day_format);
        $day_num = date("d", strtotime($your_date));
        $year_num = date("Y", strtotime($your_date));
        header('Content-Type: text/html; charset=utf-8');
        $standard = array("0", "1", "2", "3", "4", "5", "6", "7", "8", "9");
        $eastern_arabic_symbols = array("٠", "١", "٢", "٣", "٤", "٥", "٦", "٧", "٨", "٩");
        $current_date = $ar_day . ', ' . $day_num . ' ' . $ar_month . ' ' . $year_num;
        $arabic_date = str_replace($standard, $eastern_arabic_symbols, $current_date);

        return $arabic_date . " " . $newTimeFormat;
    }
}