<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateProducts extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {

        Schema::create('products', function (Blueprint $table) {
            $table->id();
            $table->string('type')->default('قطع غيار');
            $table->string('code')->nullable();
            $table->string('location')->nullable();
            $table->string('name');
            $table->double('qty')->nullable();
            $table->double('cost')->nullable();
            $table->double('price');
            $table->string('description')->nullable();
            $table->string('model')->nullable();
            $table->double('tax')->nullable();
            $table->unsignedBigInteger('branche_id')->default(1);
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->integer('notify_limit')->nullable();
            $table->timestamps();
        });

        Schema::create('clients', function (Blueprint $table) {
            $table->id();
            $table->string('name');
            $table->string('mobile');
            $table->string('id_number')->nullable();
            $table->string('model')->nullable();
            $table->string('chassis_no')->nullable();
            $table->string('car_number')->nullable();
            $table->string('kilometer_counter')->nullable();
            $table->text('note')->nullable();
            $table->unsignedBigInteger('branche_id')->default(1);
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->softDeletes();
            $table->timestamps();
        });


        Schema::create('invoices', function (Blueprint $table) {
            $table->id();
            $table->string('type');
            $table->string('payment');
            $table->string('status');
            $table->string('kilo_counter')->nullable();
            $table->date('date');
            $table->timestamp('entery_at')->nullable();
            $table->timestamp('exit_at')->nullable();
            $table->unsignedBigInteger('client_id');
            $table->foreign('client_id')->references('id')
                ->on('clients')
                ->onDelete('cascade');
            $table->double('total');
            $table->double('tax')->nullable();
            $table->double('paid');
            $table->double('due');
            $table->double('discount')->nullable()->default(0);
            $table->text('note')->nullable();
            $table->unsignedBigInteger('branche_id');
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->unsignedBigInteger('creator_id');
            $table->foreign('creator_id')
                ->references('id')
                ->on('users')
                ->onDelete('cascade');
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('details', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('invoice_id');
            $table->unsignedBigInteger('product_id');
            $table->foreign('invoice_id')->references('id')
                ->on('invoices')
                ->onDelete('cascade');
            $table->foreign('product_id')->references('id')
                    ->on('products')
                    ->onDelete('cascade');
            $table->double('cost');
            $table->double('price');
            $table->double('qty')->nullable();
            $table->double('discount')->nullable()->default(0);
            $table->double('profit')->nullable()->default(0);
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('transactions', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('creator_id')->nullable();
            $table->nullableMorphs('model');
            $table->double('value');
            $table->string('note')->nullable();
            $table->date('trans_date');
            $table->string('trans_type')->default('قبض');
            $table->unsignedBigInteger('branche_id');
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->softDeletes();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('details');
        Schema::dropIfExists('invoices');
        Schema::dropIfExists('clients');
        Schema::dropIfExists('products');
        Schema::dropIfExists('transactions');
    }
}
