<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateOffersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {

        Schema::create('offers', function (Blueprint $table) {
            $table->id();
            $table->string('type');
            $table->date('date');
            $table->unsignedBigInteger('client_id');
            $table->foreign('client_id')->references('id')
                ->on('clients')
                ->onDelete('cascade');
            $table->double('total')->nullable();
            $table->double('discount')->nullable()->default(0);
            $table->text('note')->nullable();
            $table->unsignedBigInteger('branche_id');
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->unsignedBigInteger('creator_id');
            $table->foreign('creator_id')
                ->references('id')
                ->on('users')
                ->onDelete('cascade');
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('offer_details', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('offer_id');
            $table->unsignedBigInteger('product_id');
            $table->foreign('offer_id')->references('id')
                ->on('offers')
                ->onDelete('cascade');
            $table->foreign('product_id')->references('id')
                    ->on('products')
                    ->onDelete('cascade');
            $table->double('cost');
            $table->double('price');
            $table->double('qty')->nullable();
            $table->double('discount')->nullable()->default(0);
            $table->double('profit')->nullable()->default(0);
            $table->softDeletes();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('offer_details');
        Schema::dropIfExists('offers');
    }
}
