<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateTypesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('types', function (Blueprint $table) {
            $table->id();
            $table->string('name');
            $table->timestamps();
        });
        Schema::create('status', function (Blueprint $table) {
            $table->id();
            $table->string('name');
            $table->string('color')->nullable();
            $table->string('icon')->nullable();
            $table->boolean('can_edit_invoices')->default(1);
            $table->timestamps();
        });

        Schema::table('invoices', function (Blueprint $table) {
            $table->dropColumn(['type','status']);
        });
        Schema::create('invoice_status', function (Blueprint $table) {
            $table->id();
            $table->text('note')->nullable();
            $table->string('creator_name')->nullable();
            $table->unsignedBigInteger('invoice_id');
            $table->foreign('invoice_id')->references('id')
                ->on('invoices')
                ->onDelete('cascade');
            $table->unsignedBigInteger('status_id');
            $table->foreign('status_id')->references('id')
                ->on('status')
                ->onDelete('cascade');
            $table->unsignedBigInteger('creator_id');
            $table->foreign('creator_id')
                ->references('id')
                ->on('users')
                ->onDelete('cascade');
            $table->timestamps();
        });

        Schema::table('invoices', function (Blueprint $table) {
            $table->unsignedBigInteger('type_id')->nullable()->after('id');
            $table->foreign('type_id')->references('id')
                ->on('types')
                ->onDelete('cascade');
            $table->unsignedBigInteger('status_id')->nullable()->after('id');
            $table->foreign('status_id')->references('id')
                ->on('status')
                ->onDelete('set null');
        });

    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('invoices', function (Blueprint $table) {
            $table->string('type');
            $table->string('status');
            $table->dropForeign('invoices_type_id_foreign');
            $table->dropForeign('invoices_status_id_foreign');
            $table->dropColumn(['type_id','status_id']);
        });
        Schema::dropIfExists('types');
        Schema::dropIfExists('invoice_status');
        Schema::dropIfExists('status');
    }
}
