<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreatePurchasesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('suppliers', function (Blueprint $table) {
            $table->id();
            $table->string('name');
            $table->string('mobile');
            $table->string('id_number')->nullable();
            $table->string('tax_number')->nullable();
            $table->text('note')->nullable();
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('purchases', function (Blueprint $table) {
            $table->id();
            $table->string('payment')->nullable();
            $table->string('status')->nullable();
            $table->date('date');
            $table->unsignedBigInteger('supplier_id');
            $table->foreign('supplier_id')->references('id')
                ->on('suppliers')
                ->onDelete('cascade');
            $table->double('total');
            $table->double('paid');
            $table->double('due');
            $table->double('discount')->nullable()->default(0);
            $table->text('note')->nullable();
            $table->unsignedBigInteger('branche_id');
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->unsignedBigInteger('creator_id');
            $table->foreign('creator_id')
                ->references('id')
                ->on('users')
                ->onDelete('cascade');
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('purchase_details', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('purchase_id');
            $table->unsignedBigInteger('product_id');
            $table->foreign('purchase_id')->references('id')
                ->on('purchases')
                ->onDelete('cascade');
            $table->foreign('product_id')->references('id')
                    ->on('products')
                    ->onDelete('cascade');
            $table->double('price');
            $table->double('cost');
            $table->double('qty')->nullable();
            $table->double('discount')->nullable()->default(0);
            $table->softDeletes();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('purchase_details');
        Schema::dropIfExists('purchases');
        Schema::dropIfExists('suppliers');
    }
}
