<?php

use App\Models\Lookup;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class UpdateClientAddaddress extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('lookups', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->nestedSet();
            $table->string('name');
            $table->string('type')->default('brand')->nullable();
            $table->timestamps();
        });
        $cars = array(
            array("brand" => "تويوتا", "models" => array("كورولا", "كامري", "آراف 4", "هايلاندر")),
            array("brand" => "هوندا", "models" => array("سيفيك", "أكورد", "سي آر-في", "بايلوت")),
            array("brand" => "فورد", "models" => array("إف-150", "موستانج", "إكسبلورر", "إسكيب")),
            array("brand" => "شيفروليه", "models" => array("سيلفرادو", "كامارو", "إيكوينوكس", "تاهو")),
            array("brand" => "نيسان", "models" => array("ألتيما", "ماكسيما", "روغ", "باثفايندر")),
            array("brand" => "بي إم دبليو", "models" => array("الفئة 3", "الفئة 5", "إكس 3", "إكس 5")),
            array("brand" => "مرسيدس بنز", "models" => array("الفئة سي", "الفئة إي", "جي ال سي", "جي ال إي")),
            array("brand" => "أودي", "models" => array("أي 4", "أي 6", "كيو 5", "كيو 7")),
            array("brand" => "لكزس", "models" => array("إي إس", "جي إس", "آر إكس", "إن إكس")),
            array("brand" => "هيونداي", "models" => array("إلنترا", "سوناتا", "توسان", "سانتا في")),
            array("brand" => "كيا", "models" => array("أوبتيما", "سورينتو", "سبورتاج", "تيلورايد")),
            array("brand" => "مازدا", "models" => array("مازدا 3", "مازدا 6", "سي إكس-5", "سي إكس-9")),
            array("brand" => "سوبارو", "models" => array("إمبريزا", "ليجاسي", "أوتباك", "فورستر")),
            array("brand" => "فولكس واجن", "models" => array("جيتا", "باسات", "تيجوان", "أطلس")),
            array("brand" => "فولفو", "models" => array("إس 60", "إس 90", "إكس سي 40", "إكس سي 90")),
            array("brand" => "بورش", "models" => array("911", "كايين", "باناميرا", "ماكان")),
            array("brand" => "فيراري", "models" => array("488 جي تي بي", "812 سوبرفاست", "بورتوفينو", "إس إف 90 سترادالي")),
            array("brand" => "لامبورغيني", "models" => array("أفينتادور", "هوراكان", "أوروس")),
            array("brand" => "ماكلارين", "models" => array("570 إس", "720 إس", "جي تي", "سينا")),
            array("brand" => "بوجاتي", "models" => array("شيرون", "ديفو", "سنتودييسي"))
        );
        foreach ($cars as $item) {
            $brand = Lookup::query()->create(['name' => $item['brand'], 'type' => 'brand']);
            foreach ($item['models'] as $model) {
                Lookup::query()->create(['name' => $model, 'parent_id' => $brand->id, 'type' => 'brand']);
            }
        }
        $car_colors = array("أسود", "أبيض", "رمادي", "فضي", "أحمر", "أزرق", "أخضر", "أصفر", "برتقالي", "بني");
        foreach ($car_colors as $item) {
            Lookup::query()->create(['name' => $item, 'type' => 'color']);
        }

        Schema::table('clients', function (Blueprint $table) {
            $table->string('address')->nullable();
            $table->string('taxnumber')->nullable();
            $table->string('client_type')->default('فرد');
        });
        Schema::table('suppliers', function (Blueprint $table) {
            $table->string('address')->nullable();
        });
        Schema::table('purchases', function (Blueprint $table) {
            $table->string('supplier_invoice_num')->nullable();
        });

        Schema::create('client_cars', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('client_id');
            $table->foreign('client_id')
                ->references('id')
                ->on('clients')
                ->onDelete('cascade');
            $table->string('model')->nullable();
            $table->string('car_brand')->nullable();
            $table->string('color')->nullable();
            $table->string('chassis_no')->nullable();
            $table->string('car_number')->nullable();
            $table->string('kilometer_counter')->nullable();
            $table->unsignedBigInteger('branche_id')->nullable();
            $table->foreign('branche_id')
                ->references('id')
                ->on('branches')
                ->onDelete('cascade');
            $table->string('note')->nullable();
            $table->string('delivery_name')->nullable();
            $table->string('delivery_mobile')->nullable();
            $table->timestamps();
        });

        DB::table('settings')->insert([
            ['key' => 'PriceIncludesTax', 'name' => 'السعر شامل الضريبة', 'value' => 'yes'],
            ['key' => 'rounding_up', 'name' => 'تقريب الكسور', 'value' => 'yes'],
            ['key' => 'defaultPayment', 'name' => 'طريقة الدفع الافتراضي', 'value' => 'كاش'],
        ]);
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('clients', function (Blueprint $table) {
            $table->dropColumn(['address', 'taxnumber', 'client_type']);
        });
        Schema::table('suppliers', function (Blueprint $table) {
            $table->dropColumn(['address']);
        });
        Schema::table('purchases', function (Blueprint $table) {
            $table->dropColumn(['supplier_invoice_num']);
        });
        Schema::dropIfExists('client_cars');
        Schema::dropIfExists('lookups');

        DB::table('settings')->wherein('key', [
            'PriceIncludesTax',
            'rounding_up',
            'defaultPayment'
        ])->delete();
    }
}