<?php

namespace Database\Seeders;

use App\Models\Department;
use App\Models\Mission;
use App\Models\Role;
use App\Models\User;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Permission;
use Faker\Factory as Faker;

class DepartmentSeeder extends Seeder
{
    protected $faker;
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        try{
            DB::beginTransaction();
            $this->faker = Faker::create('ar_JO');
            Role::query()->where('id','>',1)->delete();
            Role::query()->insert([
                ['name'=>'مسئول الأستقبال','guard_name' => 'web'],
                ['name'=>'مسئول الصيانة','guard_name' => 'web'],
                ['name'=>'مسئول قطع الغيار','guard_name' => 'web'],
                ['name'=>'مسئول الضمان','guard_name' => 'web'],
                ['name'=>'المدير المالي','guard_name' => 'web'],
            ]);
            $permisionsList = [
                'Create OrderTasks','Edit OrderTasks','Delete OrderTasks','List OrderTasks',
                'Create Clients','Edit Clients','Delete Clients','List Clients',
                'Create Invoices','Edit Invoices','Delete Invoices','List Invoices','Show Invoices'

            ];
            $inserLsit = [];
            foreach($permisionsList as $perm){
                $check = Permission::where('name',$perm)->count();
                if($check) continue;
                $inserLsit[] =
                ['name' => $perm,'guard_name' => 'web'];

            }
            Permission::insert($inserLsit);
            foreach(Role::where('id','>',1)->get() as $k=>$role){
                $role->syncPermissions($permisionsList);
                $email = $this->faker->unique()->safeEmail();
                $user = User::query()->firstOrCreate(
                            ['email'=>$email],
                            [
                                'name'=>$this->faker->firstName,
                                'email'=>$k+1,
                                'password'=>bcrypt('123456')
                            ]);
                $user->syncRoles($role->name);
            }
            //DB::statement('SET FOREIGN_KEY_CHECKS=0');
            DB::table('departments')->truncate();
            DB::table('missions')->truncate();
            Department::query()->insert([
                ['name'=>'قسم الأستقبال'],
                ['name'=>'قسم الصيانة'],
                ['name'=>'قسم قطع الغيار'],
                ['name'=>'قسم الضمان'],
                ['name'=>'قسم المالية'],
            ]);
            Mission::query()->insert([
                [
                    'department_id'=>1,
                    'title'=>'إنشاء كارت صيانة',
                    'description'=>''
                ],
                [
                    'department_id'=>2,
                    'title'=>'فحص المركبة',
                    'description'=>''
                ],
                [
                    'department_id'=>3,
                    'title'=>'قطع الغيار',
                    'description'=>''
                ],
                [
                    'department_id'=>4,
                    'title'=>'تحديد التغطية',
                    'description'=>''
                ],
                [
                    'department_id'=>1,
                    'title'=>'إنهاء كارت الصيانة',
                    'description'=>''
                ],
            ]);
            //DB::statement('SET FOREIGN_KEY_CHECKS=1');
            DB::commit();
        }catch (\Exception $e){
            DB::rollBack();
            //return back()->with('alert-danger', ' حدث خطأ اثناء الاضافة حاول مرة أخرى وتأكد من إدخال البيانات بطريقة صحيحة '.$e->getMessage());
            dd($e->getMessage());
        }
    }
}
