<?php

use Illuminate\Support\Facades\Route;
use \Illuminate\Routing\Router;
use Illuminate\Support\Facades\Auth;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


// Route::group(['namespace' => 'Auth'], function (Router $router) {
//     $router->get('login', 'LoginController@showLoginForm')->name('show.login.form');
//     $router->post('login', 'LoginController@login')->name('login');
//     $router->get('logout', 'LoginController@logout')->name('logout');
// });

Auth::routes();
Route::group(['middleware' => ['auth']], function (Router $router) {
    $router->get('purchase/print/{id}', 'PurchaseController@print')->name('purchase.print');
    $router->get('invoice/print/{id}', 'InvoicesController@print')->name('invoice.print');
    $router->get('returns/print/{id}', 'ReturnsController@print')->name('returns.print');
    $router->get('/', 'HomeController@index')->name('home');
    $router->group(['middleware' => 'authorize'], function (Router $router) {
        $router->resource('roles', 'RolesController')->except('show');
        $router->resource('users', 'UsersController');
        $router->resource('clients', 'ClientController');
        $router->resource('products', 'ProductController')->except('show');
        $router->resource('appointments', 'AppointmentController')->except('show');
        $router->any('products/import', 'ExcelController@importProducts')->name('products.import');
        $router->resource('branches', 'BrancheController')->except('show');
        $router->resource('departments', 'DepartmentController')->except('show');
        $router->resource('missions', 'MissionController')->except('show');
        $router->resource('ordertasks', 'OrderTaskController');
        $router->resource('suppliers', 'SupplierController');
        $router->resource('purchases', 'PurchaseController');
        $router->resource('invoices', 'InvoicesController');
        $router->resource('returns', 'ReturnsController');
        $router->any('return/qtyreview', 'ReturnsController@qtyReview')->name('returns.qtyReview');
        $router->any('order/changestatus/{order_id}', 'InvoicesController@addStatus')->name('invoices.addStatus');
        $router->any('order/warrantyreview/{order_id}', 'InvoicesController@warrantyReview')->name('invoices.warrantyReview');
        $router->any('order/qtyreview', 'InvoicesController@qtyReview')->name('invoices.qtyReview');

        $router->resource('workorders', 'WorkOrdersController');
        $router->any('makeinvoice/{order}', 'WorkOrdersController@MakeInvoice')->name('workorders.makeinvoice');
        $router->resource('offers', 'OffersController');
        $router->resource('transactions', 'TransactionsController');
        $router->resource('status', 'StatusController')->except('show');
        $router->resource('types', 'TypeController')->except('show');
        $router->any('invoice/{order_id}', 'InvoicesController@addPayment')->name('invoices.addPayment');
        $router->any('purchase/{order_id}', 'PurchaseController@addPayment')->name('purchases.addWithdraw');
        $router->get('setting', array('as' => 'setting.index', 'uses' => 'SettingController@index'));
        $router->post('setting/edit', array('as' => 'setting.edit', 'uses' => 'SettingController@update'));
    });
    $router->get('product/list', 'ProductController@getProductsList')->name('getProductsList');
    $router->get('supplier/list', 'SupplierController@getSuppliersList')->name('getSuppliersList');
    $router->get('client/list', 'ClientController@getClientsList')->name('getClientsList');
    $router->get('clearCache', 'HomeController@clearCache')->name('clearCache');
    $router->get('migrate', 'HomeController@migrate')->name('migrate');
    $router->any('restore', 'HomeController@restore')->name('restore');
    $router->get('cleanDB', 'HomeController@cleanDB')->name('cleanDB');
    $router->get('backup', 'HomeController@backup')->name('backup');
    $router->get('carsearch', 'HomeController@carsearch')->name('carsearch');
    $router->any('ordertasks/update2/{ordertask}', 'OrderTaskController@update')->name('ordertasks.update2');
    $router->get('ordertasks/edit/{ordertask}', 'OrderTaskController@edit')->name('ordertasks.edit2');
    $router->get('ordertasks/{ordertask}', 'OrderTaskController@show')->name('ordertasks.show2');
    $router->get('ordertasks/preview/{ordertask}', 'OrderTaskController@preview')->name('ordertasks.preview');
    $router->get('serviceform/{ordertask}', 'OrderTaskController@serviceform')->name('ordertasks.serviceform');
    $router->get('exceptionrequest/{ordertask}', 'OrderTaskController@exceptionrequest')->name('ordertasks.exceptionrequest');

    $router->any('ordertasks/uploadfiles/{ordertask}', 'OrderTaskController@uploadfiles')->name('ordertasks.uploadfiles');
    $router->post('task/save', 'HomeController@saveTask')->name('task.save');
    $router->get('invoice/details/{id}', 'InvoicesController@show')->name('invoice.show');

    $router->resource('lookups', 'LookupController')->except('show');
    $router->resource('clientcars', 'ClientCarController')->except('show');
    $router->get('getClientCarsList', 'ClientCarController@getClientCarsList')->name('getClientCarsList');
    $router->get('getmodels', 'LookupController@getmodels')->name('getmodels');
    $router->get('getbrands', 'LookupController@getbrands')->name('getbrands');
    $router->get('getcolors', 'LookupController@getcolors')->name('getcolors');

});